@@ -1,4 +1,4 @@
-#   Copyright 2012 OpenStack, LLC.
+#   Copyright 2012 OpenStack Foundation
 #
 #   Licensed under the Apache License, Version 2.0 (the "License"); you may
 #   not use this file except in compliance with the License. You may obtain
@@ -20,6 +20,8 @@ from cinder.api.openstack import wsgi
 from cinder import db
 from cinder import exception
 from cinder.openstack.common import log as logging
+from cinder.openstack.common import strutils
+from cinder import rpc
 from cinder import volume
 
 
@@ -80,10 +82,20 @@ class AdminController(wsgi.Controller):
         msg = _("Updating %(resource)s '%(id)s' with '%(update)r'")
         LOG.debug(msg, {'resource': self.resource_name, 'id': id,
                         'update': update})
+
+        notifier_info = dict(id=id, update=update)
+        notifier = rpc.get_notifier('volumeStatusUpdate')
+        notifier.info(context, self.collection + '.reset_status.start',
+                      notifier_info)
+
         try:
             self._update(context, id, update)
-        except exception.NotFound, e:
+        except exception.NotFound as e:
             raise exc.HTTPNotFound(e)
+
+        notifier.info(context, self.collection + '.reset_status.end',
+                      notifier_info)
+
         return webob.Response(status_int=202)
 
     @wsgi.action('os-force_delete')
@@ -125,10 +137,7 @@ class VolumeAdminController(AdminController):
 
     @wsgi.action('os-force_detach')
     def _force_detach(self, req, id, body):
-        """
-        Roll back a bad detach after the volume been disconnected from
-        the hypervisor.
-        """
+        """Roll back a bad detach after the volume been disconnected."""
         context = req.environ['cinder.context']
         self.authorize(context, 'force_detach')
         try:
@@ -140,6 +149,55 @@ class VolumeAdminController(AdminController):
         self.volume_api.detach(context, volume)
         return webob.Response(status_int=202)
 
+    @wsgi.action('os-migrate_volume')
+    def _migrate_volume(self, req, id, body):
+        """Migrate a volume to the specified host."""
+        context = req.environ['cinder.context']
+        self.authorize(context, 'migrate_volume')
+        try:
+            volume = self._get(context, id)
+        except exception.NotFound:
+            raise exc.HTTPNotFound()
+        params = body['os-migrate_volume']
+        try:
+            host = params['host']
+        except KeyError:
+            raise exc.HTTPBadRequest("Must specify 'host'")
+        force_host_copy = params.get('force_host_copy', False)
+        if isinstance(force_host_copy, basestring):
+            try:
+                force_host_copy = strutils.bool_from_string(force_host_copy,
+                                                            strict=True)
+            except ValueError:
+                raise exc.HTTPBadRequest("Bad value for 'force_host_copy'")
+        elif not isinstance(force_host_copy, bool):
+            raise exc.HTTPBadRequest("'force_host_copy' not string or bool")
+        self.volume_api.migrate_volume(context, volume, host, force_host_copy)
+        return webob.Response(status_int=202)
+
+    @wsgi.action('os-migrate_volume_completion')
+    def _migrate_volume_completion(self, req, id, body):
+        """Complete an in-progress migration."""
+        context = req.environ['cinder.context']
+        self.authorize(context, 'migrate_volume_completion')
+        try:
+            volume = self._get(context, id)
+        except exception.NotFound:
+            raise exc.HTTPNotFound()
+        params = body['os-migrate_volume_completion']
+        try:
+            new_volume_id = params['new_volume']
+        except KeyError:
+            raise exc.HTTPBadRequest("Must specify 'new_volume'")
+        try:
+            new_volume = self._get(context, new_volume_id)
+        except exception.NotFound:
+            raise exc.HTTPNotFound()
+        error = params.get('error', False)
+        ret = self.volume_api.migrate_volume_completion(context, volume,
+                                                        new_volume, error)
+        return {'save_volume_id': ret}
+
 
 class SnapshotAdminController(AdminController):
     """AdminController for Snapshots."""
