@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2011 OpenStack Foundation
 # All Rights Reserved.
 #
@@ -23,15 +21,18 @@ from cinder.api import xmlutil
 from cinder import db
 from cinder.db.sqlalchemy import api as sqlalchemy_api
 from cinder import exception
+from cinder.openstack.common.gettextutils import _
 from cinder.openstack.common import strutils
 from cinder import quota
 
 
 QUOTAS = quota.QUOTAS
+NON_QUOTA_KEYS = ['tenant_id', 'id']
 
 
 authorize_update = extensions.extension_authorizer('volume', 'quotas:update')
 authorize_show = extensions.extension_authorizer('volume', 'quotas:show')
+authorize_delete = extensions.extension_authorizer('volume', 'quotas:delete')
 
 
 class QuotaTemplate(xmlutil.TemplateBuilder):
@@ -49,7 +50,7 @@ class QuotaTemplate(xmlutil.TemplateBuilder):
 class QuotaSetsController(wsgi.Controller):
 
     def _format_quota_set(self, project_id, quota_set):
-        """Convert the quota object to a result dict"""
+        """Convert the quota object to a result dict."""
 
         quota_set['id'] = str(project_id)
 
@@ -101,18 +102,31 @@ class QuotaSetsController(wsgi.Controller):
         authorize_update(context)
         project_id = id
         if not self.is_valid_body(body, 'quota_set'):
-            msg = _("Missing required element quota_set in request body.")
+            msg = (_("Missing required element quota_set in request body."))
+            raise webob.exc.HTTPBadRequest(explanation=msg)
+
+        bad_keys = []
+
+        for key, value in body['quota_set'].items():
+            if (key not in QUOTAS and key not in NON_QUOTA_KEYS):
+                bad_keys.append(key)
+                continue
+
+        if len(bad_keys) > 0:
+            msg = _("Bad key(s) in quota set: %s") % ",".join(bad_keys)
             raise webob.exc.HTTPBadRequest(explanation=msg)
 
         for key in body['quota_set'].keys():
-            if key in QUOTAS:
-                value = self._validate_quota_limit(body['quota_set'][key])
-                try:
-                    db.quota_update(context, project_id, key, value)
-                except exception.ProjectQuotaNotFound:
-                    db.quota_create(context, project_id, key, value)
-                except exception.AdminRequired:
-                    raise webob.exc.HTTPForbidden()
+            if key in NON_QUOTA_KEYS:
+                continue
+
+            value = self._validate_quota_limit(body['quota_set'][key])
+            try:
+                db.quota_update(context, project_id, key, value)
+            except exception.ProjectQuotaNotFound:
+                db.quota_create(context, project_id, key, value)
+            except exception.AdminRequired:
+                raise webob.exc.HTTPForbidden()
         return {'quota_set': self._get_quotas(context, id)}
 
     @wsgi.serializers(xml=QuotaTemplate)
@@ -121,9 +135,20 @@ class QuotaSetsController(wsgi.Controller):
         authorize_show(context)
         return self._format_quota_set(id, QUOTAS.get_defaults(context))
 
+    @wsgi.serializers(xml=QuotaTemplate)
+    def delete(self, req, id):
+
+        context = req.environ['cinder.context']
+        authorize_delete(context)
+
+        try:
+            db.quota_destroy_all_by_project(context, id)
+        except exception.AdminRequired:
+            raise webob.exc.HTTPForbidden()
+
 
 class Quotas(extensions.ExtensionDescriptor):
-    """Quotas management support"""
+    """Quota management support."""
 
     name = "Quotas"
     alias = "os-quota-sets"
