@@ -11,17 +11,18 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-from http import HTTPStatus
 
-from oslo_log import log as logging
 import webob
+from webob import exc
 
 from cinder.api import extensions
 from cinder.api.openstack import wsgi
-from cinder.policies import manageable_volumes as policy
+from cinder import exception
+from cinder.openstack.common import log as logging
 from cinder import volume
 
 LOG = logging.getLogger(__name__)
+authorize = extensions.extension_authorizer('volume', 'volume_unmanage')
 
 
 class VolumeUnmanageController(wsgi.Controller):
@@ -29,7 +30,7 @@ class VolumeUnmanageController(wsgi.Controller):
         super(VolumeUnmanageController, self).__init__(*args, **kwargs)
         self.volume_api = volume.API()
 
-    @wsgi.response(HTTPStatus.ACCEPTED)
+    @wsgi.response(202)
     @wsgi.action('os-unmanage')
     def unmanage(self, req, id, body):
         """Stop managing a volume.
@@ -47,14 +48,20 @@ class VolumeUnmanageController(wsgi.Controller):
         attached to an instance.
         """
         context = req.environ['cinder.context']
+        authorize(context)
 
-        LOG.info("Unmanage volume with id: %s", id)
+        LOG.audit(_("Unmanage volume with id: %s"), id, context=context)
 
-        # Not found exception will be handled at the wsgi level
-        vol = self.volume_api.get(context, id)
-        context.authorize(policy.UNMANAGE_POLICY, target_obj=vol)
-        self.volume_api.delete(context, vol, unmanage_only=True)
-        return webob.Response(status_int=HTTPStatus.ACCEPTED)
+        try:
+            vol = self.volume_api.get(context, id)
+            self.volume_api.delete(context, vol, unmanage_only=True)
+        except exception.NotFound:
+            msg = _("Volume could not be found")
+            raise exc.HTTPNotFound(explanation=msg)
+        except exception.VolumeAttached:
+            msg = _("Volume cannot be deleted while in attached state")
+            raise exc.HTTPBadRequest(explanation=msg)
+        return webob.Response(status_int=202)
 
 
 class Volume_unmanage(extensions.ExtensionDescriptor):
@@ -62,6 +69,7 @@ class Volume_unmanage(extensions.ExtensionDescriptor):
 
     name = "VolumeUnmanage"
     alias = "os-volume-unmanage"
+    namespace = "http://docs.openstack.org/volume/ext/volume-unmanage/api/v1.1"
     updated = "2012-05-31T00:00:00+00:00"
 
     def get_controller_extensions(self):
