@@ -14,17 +14,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
-import six
-from six.moves import http_client
 import webob.dec
 import webob.exc
 
-from cinder.api import api_utils
 from cinder.api.openstack import wsgi
 from cinder import exception
-from cinder.i18n import _
-from cinder.wsgi import common as base_wsgi
+from cinder.openstack.common import log as logging
+from cinder import utils
+from cinder import wsgi as base_wsgi
 
 
 LOG = logging.getLogger(__name__)
@@ -38,29 +35,22 @@ class FaultWrapper(base_wsgi.Middleware):
     @staticmethod
     def status_to_type(status):
         if not FaultWrapper._status_to_type:
-            for clazz in api_utils.walk_class_hierarchy(webob.exc.HTTPError):
+            for clazz in utils.walk_class_hierarchy(webob.exc.HTTPError):
                 FaultWrapper._status_to_type[clazz.code] = clazz
         return FaultWrapper._status_to_type.get(
             status, webob.exc.HTTPInternalServerError)()
 
     def _error(self, inner, req):
-        if isinstance(inner, UnicodeDecodeError):
-            msg = _("Error decoding your request. Either the URL or the "
-                    "request body contained characters that could not be "
-                    "decoded by Cinder.")
-            return wsgi.Fault(webob.exc.HTTPBadRequest(explanation=msg))
-        if not isinstance(inner, exception.QuotaError):
-            LOG.exception("Caught error: %(type)s %(error)s",
-                          {'type': type(inner),
-                           'error': inner})
+        LOG.exception(_("Caught error: %s"), unicode(inner))
+
         safe = getattr(inner, 'safe', False)
         headers = getattr(inner, 'headers', None)
-        status = getattr(inner, 'code', http_client.INTERNAL_SERVER_ERROR)
+        status = getattr(inner, 'code', 500)
         if status is None:
-            status = http_client.INTERNAL_SERVER_ERROR
+            status = 500
 
         msg_dict = dict(url=req.url, status=status)
-        LOG.info("%(url)s returned with HTTP %(status)s", msg_dict)
+        LOG.info(_("%(url)s returned with HTTP %(status)d") % msg_dict)
         outer = self.status_to_type(status)
         if headers:
             outer.headers = headers
@@ -73,7 +63,7 @@ class FaultWrapper(base_wsgi.Middleware):
         # including those that are safe to expose, see bug 1021373
         if safe:
             msg = (inner.msg if isinstance(inner, exception.CinderException)
-                   else six.text_type(inner))
+                   else unicode(inner))
             params = {'exception': inner.__class__.__name__,
                       'explanation': msg}
             outer.explanation = _('%(exception)s: %(explanation)s') % params
