@@ -74,16 +74,12 @@ class LimitsTemplate(xmlutil.TemplateBuilder):
         return xmlutil.MasterTemplate(root, 1, nsmap=limits_nsmap)
 
 
-class LimitsController(object):
-    """
-    Controller for accessing limits in the OpenStack API.
-    """
+class LimitsController(wsgi.Controller):
+    """Controller for accessing limits in the OpenStack API."""
 
     @wsgi.serializers(xml=LimitsTemplate)
     def index(self, req):
-        """
-        Return all global and rate limit information.
-        """
+        """Return all global and rate limit information."""
         context = req.environ['cinder.context']
         quotas = QUOTAS.get_project_quotas(context, context.project_id,
                                            usages=False)
@@ -102,9 +98,7 @@ def create_resource():
 
 
 class Limit(object):
-    """
-    Stores information about a limit for HTTP requests.
-    """
+    """Stores information about a limit for HTTP requests."""
 
     UNITS = {
         1: "SECOND",
@@ -116,8 +110,7 @@ class Limit(object):
     UNIT_MAP = dict([(v, k) for k, v in UNITS.items()])
 
     def __init__(self, verb, uri, regex, value, unit):
-        """
-        Initialize a new `Limit`.
+        """Initialize a new `Limit`.
 
         @param verb: HTTP verb (POST, PUT, etc.)
         @param uri: Human-readable URI
@@ -147,8 +140,7 @@ class Limit(object):
         self.error_message = msg % self.__dict__
 
     def __call__(self, verb, url):
-        """
-        Represents a call to this limit from a relevant request.
+        """Represent a call to this limit from a relevant request.
 
         @param verb: string http verb (POST, GET, etc.)
         @param url: string URL
@@ -216,14 +208,13 @@ DEFAULT_LIMITS = [
 
 
 class RateLimitingMiddleware(base_wsgi.Middleware):
-    """
-    Rate-limits requests passing through this middleware. All limit information
-    is stored in memory for this implementation.
+    """Rate-limits requests passing through this middleware.
+
+    All limit information is stored in memory for this implementation.
     """
 
     def __init__(self, application, limits=None, limiter=None, **kwargs):
-        """
-        Initialize new `RateLimitingMiddleware`, which wraps the given WSGI
+        """Initialize new `RateLimitingMiddleware`, which wraps the given WSGI
         application and sets up the given limits.
 
         @param application: WSGI application to wrap
@@ -248,13 +239,12 @@ class RateLimitingMiddleware(base_wsgi.Middleware):
 
     @webob.dec.wsgify(RequestClass=wsgi.Request)
     def __call__(self, req):
-        """
-        Represents a single call through this middleware. We should record the
-        request if we have a limit relevant to it. If no limit is relevant to
-        the request, ignore it.
+        """Represents a single call through this middleware.
 
-        If the request should be rate limited, return a fault telling the user
-        they are over the limit and need to retry later.
+        We should record the request if we have a limit relevant to it.
+        If no limit is relevant to the request, ignore it.  If the request
+        should be rate limited, return a fault telling the user they are
+        over the limit and need to retry later.
         """
         verb = req.method
         url = req.url
@@ -278,13 +268,10 @@ class RateLimitingMiddleware(base_wsgi.Middleware):
 
 
 class Limiter(object):
-    """
-    Rate-limit checking class which handles limits in memory.
-    """
+    """Rate-limit checking class which handles limits in memory."""
 
     def __init__(self, limits, **kwargs):
-        """
-        Initialize the new `Limiter`.
+        """Initialize the new `Limiter`.
 
         @param limits: List of `Limit` objects
         """
@@ -298,14 +285,11 @@ class Limiter(object):
                 self.levels[username] = self.parse_limits(value)
 
     def get_limits(self, username=None):
-        """
-        Return the limits for a given user.
-        """
+        """Return the limits for a given user."""
         return [limit.display() for limit in self.levels[username]]
 
     def check_for_delay(self, verb, url, username=None):
-        """
-        Check the given verb/user/user triplet for limit.
+        """Check the given verb/user/user triplet for limit.
 
         @return: Tuple of delay (in seconds) and error message (or None, None)
         """
@@ -329,9 +313,9 @@ class Limiter(object):
     # default limit parsing.
     @staticmethod
     def parse_limits(limits):
-        """
-        Convert a string into a list of Limit instances.  This
-        implementation expects a semicolon-separated sequence of
+        """Convert a string into a list of Limit instances.
+
+        This implementation expects a semicolon-separated sequence of
         parenthesized groups, where each group contains a
         comma-separated sequence consisting of HTTP method,
         user-readable URI, a URI reg-exp, an integer number of
@@ -384,8 +368,9 @@ class Limiter(object):
 
 
 class WsgiLimiter(object):
-    """
-    Rate-limit checking from a WSGI application. Uses an in-memory `Limiter`.
+    """Rate-limit checking from a WSGI application.
+
+    Uses an in-memory `Limiter`.
 
     To use, POST ``/<username>`` with JSON data such as::
 
@@ -400,8 +385,7 @@ class WsgiLimiter(object):
     """
 
     def __init__(self, limits=None):
-        """
-        Initialize the new `WsgiLimiter`.
+        """Initialize the new `WsgiLimiter`.
 
         @param limits: List of `Limit` objects
         """
@@ -409,10 +393,11 @@ class WsgiLimiter(object):
 
     @webob.dec.wsgify(RequestClass=wsgi.Request)
     def __call__(self, request):
-        """
-        Handles a call to this application. Returns 204 if the request is
-        acceptable to the limiter, else a 403 is returned with a relevant
-        header indicating when the request *will* succeed.
+        """Handles a call to this application.
+
+        Returns 204 if the request is acceptable to the limiter, else a 403
+        is returned with a relevant header indicating when the request
+        *will* succeed.
         """
         if request.method != "POST":
             raise webob.exc.HTTPMethodNotAllowed()
@@ -436,13 +421,10 @@ class WsgiLimiter(object):
 
 
 class WsgiLimiterProxy(object):
-    """
-    Rate-limit requests based on answers from a remote source.
-    """
+    """Rate-limit requests based on answers from a remote source."""
 
     def __init__(self, limiter_address):
-        """
-        Initialize the new `WsgiLimiterProxy`.
+        """Initialize the new `WsgiLimiterProxy`.
 
         @param limiter_address: IP/port combination of where to request limit
         """
@@ -473,9 +455,7 @@ class WsgiLimiterProxy(object):
     # decisions are made by a remote server.
     @staticmethod
     def parse_limits(limits):
-        """
-        Ignore a limits string--simply doesn't apply for the limit
-        proxy.
+        """Ignore a limits string--simply doesn't apply for the limit proxy.
 
         @return: Empty list.
         """
