@@ -14,37 +14,40 @@
 #    under the License.
 
 from cinder.api import common
+from cinder.openstack.common import log as logging
+
+
+LOG = logging.getLogger(__name__)
 
 
 class ViewBuilder(common.ViewBuilder):
     """Model QoS specs API responses as a python dictionary."""
 
-    _collection_name = "qos-specs"
+    _collection_name = "qos_specs"
 
     def __init__(self):
         """Initialize view builder."""
         super(ViewBuilder, self).__init__()
 
-    def summary_list(self, request, qos_specs, qos_count=None):
+    def summary_list(self, request, qos_specs):
         """Show a list of qos_specs without many details."""
-        return self._list_view(self.detail, request, qos_specs, qos_count)
+        return self._list_view(self.detail, request, qos_specs)
 
     def summary(self, request, qos_spec):
         """Generic, non-detailed view of a qos_specs."""
-        return self.detail(request, qos_spec)
+        return {
+            'qos_specs': qos_spec,
+            'links': self._get_links(request,
+                                     qos_spec['id']),
+        }
 
     def detail(self, request, qos_spec):
         """Detailed view of a single qos_spec."""
-        # TODO(zhiteng) Add associations to detailed view
+        #TODO(zhiteng) Add associations to detailed view
         return {
-            'qos_specs': {
-                'id': qos_spec.id,
-                'name': qos_spec.name,
-                'consumer': qos_spec.consumer,
-                'specs': qos_spec.specs,
-            },
+            'qos_specs': qos_spec,
             'links': self._get_links(request,
-                                     qos_spec.id),
+                                     qos_spec['id']),
         }
 
     def associations(self, request, associates):
@@ -53,14 +56,9 @@ class ViewBuilder(common.ViewBuilder):
             'qos_associations': associates
         }
 
-    def _list_view(self, func, request, qos_specs, qos_count=None):
+    def _list_view(self, func, request, qos_specs):
         """Provide a view for a list of qos_specs."""
         specs_list = [func(request, specs)['qos_specs'] for specs in qos_specs]
-        specs_links = self._get_collection_links(request, qos_specs,
-                                                 self._collection_name,
-                                                 qos_count)
         specs_dict = dict(qos_specs=specs_list)
-        if specs_links:
-            specs_dict['qos_specs_links'] = specs_links
 
         return specs_dict
