@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -27,11 +25,12 @@ stepping stone.
 
 """
 
-import os
 import socket
 
 from oslo.config import cfg
 
+from cinder.openstack.common.gettextutils import _
+
 
 CONF = cfg.CONF
 
@@ -56,23 +55,12 @@ def _get_my_ip():
 
 
 core_opts = [
-    cfg.StrOpt('connection_type',
-               default=None,
-               help='Virtualization api connection type : libvirt, xenapi, '
-                    'or fake'),
     cfg.StrOpt('api_paste_config',
                default="api-paste.ini",
                help='File name for the paste.deploy config for cinder-api'),
-    cfg.StrOpt('pybasedir',
-               default=os.path.abspath(os.path.join(os.path.dirname(__file__),
-                                                    '..',
-                                                    '..')),
-               help='Directory where the cinder python module is installed'),
-    cfg.StrOpt('bindir',
-               default='$pybasedir/bin',
-               help='Directory where cinder binaries are installed'),
     cfg.StrOpt('state_path',
-               default='$pybasedir',
+               default='/var/lib/cinder',
+               deprecated_name='pybasedir',
                help="Top-level directory for maintaining cinder's state"), ]
 
 debug_opts = [
@@ -129,10 +117,10 @@ global_opts = [
                help='the topic volume backup nodes listen on'),
     cfg.BoolOpt('enable_v1_api',
                 default=True,
-                help=_("Deploy v1 of the Cinder API. ")),
+                help=_("Deploy v1 of the Cinder API.")),
     cfg.BoolOpt('enable_v2_api',
                 default=True,
-                help=_("Deploy v2 of the Cinder API. ")),
+                help=_("Deploy v2 of the Cinder API.")),
     cfg.BoolOpt('api_rate_limit',
                 default=True,
                 help='whether to rate limit the api'),
@@ -167,9 +155,6 @@ global_opts = [
                     'If this is not set then we use the value from the '
                     'storage_availability_zone option as the default '
                     'availability_zone for new volumes.'),
-    cfg.ListOpt('memcached_servers',
-                default=None,
-                help='Memcached servers or None for in process cache.'),
     cfg.StrOpt('default_volume_type',
                default=None,
                help='default volume type to use'),
@@ -177,9 +162,6 @@ global_opts = [
                default='month',
                help='time period to generate volume usages for.  '
                     'Time period must be hour, day, month or year'),
-    cfg.StrOpt('root_helper',
-               default='sudo',
-               help='Deprecated: command to use for running commands as root'),
     cfg.StrOpt('rootwrap_config',
                default='/etc/cinder/rootwrap.conf',
                help='Path to the rootwrap configuration file to use for '
