@@ -13,12 +13,16 @@
 from sqlalchemy import Boolean, Column, DateTime
 from sqlalchemy import Integer, MetaData, String, Table, ForeignKey
 
+from cinder.openstack.common import log as logging
+
+LOG = logging.getLogger(__name__)
+
 
 def upgrade(migrate_engine):
     meta = MetaData()
     meta.bind = migrate_engine
 
-    Table('snapshots', meta, autoload=True)
+    snapshots = Table('snapshots', meta, autoload=True)
 
     # New table
     snapshot_metadata = Table(
@@ -35,4 +39,21 @@ def upgrade(migrate_engine):
         mysql_engine='InnoDB'
     )
 
-    snapshot_metadata.create()
+    try:
+        snapshot_metadata.create()
+    except Exception:
+        LOG.error(_("Table |%s| not created!"), repr(snapshot_metadata))
+        raise
+
+
+def downgrade(migrate_engine):
+    meta = MetaData()
+    meta.bind = migrate_engine
+    snapshot_metadata = Table('snapshot_metadata',
+                              meta,
+                              autoload=True)
+    try:
+        snapshot_metadata.drop()
+    except Exception:
+        LOG.error(_("snapshot_metadata table not dropped"))
+        raise
