@@ -1,3 +1,5 @@
+BEGIN TRANSACTION;
+
 CREATE TABLE volumes_v10 (
     created_at DATETIME,
     updated_at DATETIME,
@@ -59,3 +61,4 @@ INSERT INTO volumes_v10
 
 DROP TABLE volumes;
 ALTER TABLE volumes_v10 RENAME TO volumes;
+COMMIT;
