@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2011 X.commerce, a business unit of eBay Inc.
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
@@ -26,7 +24,6 @@ from sqlalchemy import Column, Integer, String, Text, schema
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import ForeignKey, DateTime, Boolean
 from sqlalchemy.orm import relationship, backref
-from sqlalchemy.orm.collections import attribute_mapped_collection
 
 from oslo.config import cfg
 
@@ -68,14 +65,7 @@ class Service(BASE, CinderBase):
     report_count = Column(Integer, nullable=False, default=0)
     disabled = Column(Boolean, default=False)
     availability_zone = Column(String(255), default='cinder')
-
-
-class CinderNode(BASE, CinderBase):
-    """Represents a running cinder service on a host."""
-
-    __tablename__ = 'cinder_nodes'
-    id = Column(Integer, primary_key=True)
-    service_id = Column(Integer, ForeignKey('services.id'), nullable=True)
+    disabled_reason = Column(String(255))
 
 
 class Volume(BASE, CinderBase):
@@ -345,7 +335,7 @@ class Reservation(BASE, CinderBase):
 
 
 class Snapshot(BASE, CinderBase):
-    """Represents a block storage device that can be attached to a VM."""
+    """Represents a snapshot of volume."""
     __tablename__ = 'snapshots'
     id = Column(String(36), primary_key=True)
 
