@@ -11,8 +11,6 @@
 # under the License.
 
 import ast
-import os
-import shutil
 import tempfile
 import webob
 
@@ -27,6 +25,7 @@ from cinder.openstack.common import timeutils
 from cinder import test
 from cinder.tests.api import fakes
 from cinder.tests.api.v2 import stubs
+from cinder.tests import cast_as_call
 from cinder.volume import api as volume_api
 
 CONF = cfg.CONF
@@ -44,15 +43,16 @@ class AdminActionsTest(test.TestCase):
 
     def setUp(self):
         super(AdminActionsTest, self).setUp()
+
         self.tempdir = tempfile.mkdtemp()
         self.flags(rpc_backend='cinder.openstack.common.rpc.impl_fake')
-        self.flags(lock_path=self.tempdir)
-        self.volume_api = volume_api.API()
-        self.stubs.Set(brick_lvm.LVM, '_vg_exists', lambda x: True)
+        self.flags(lock_path=self.tempdir,
+                   disable_process_locking=True)
 
-    def tearDown(self):
-        shutil.rmtree(self.tempdir)
-        super(AdminActionsTest, self).tearDown()
+        self.volume_api = volume_api.API()
+        cast_as_call.mock_cast_as_call(self.volume_api.volume_rpcapi.client)
+        cast_as_call.mock_cast_as_call(self.volume_api.scheduler_rpcapi.client)
+        self.stubs.Set(brick_lvm.LVM, '_vg_exists', lambda x: True)
 
     def test_reset_status_as_admin(self):
         # admin context
@@ -76,7 +76,7 @@ class AdminActionsTest(test.TestCase):
     def test_reset_status_as_non_admin(self):
         # current status is 'error'
         volume = db.volume_create(context.get_admin_context(),
-                                  {'status': 'error'})
+                                  {'status': 'error', 'size': 1})
         req = webob.Request.blank('/v2/fake/volumes/%s/action' % volume['id'])
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
@@ -96,7 +96,7 @@ class AdminActionsTest(test.TestCase):
         # admin context
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
-        volume = db.volume_create(ctx, {'status': 'available'})
+        volume = db.volume_create(ctx, {'status': 'available', 'size': 1})
         req = webob.Request.blank('/v2/fake/volumes/%s/action' % volume['id'])
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
@@ -115,7 +115,7 @@ class AdminActionsTest(test.TestCase):
         # admin context
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
-        volume = db.volume_create(ctx, {'status': 'available'})
+        volume = db.volume_create(ctx, {'status': 'available', 'size': 1})
         req = webob.Request.blank('/v2/fake/volumes/%s/action' % volume['id'])
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
@@ -153,7 +153,8 @@ class AdminActionsTest(test.TestCase):
         # admin context
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
-        volume = db.volume_create(ctx, {'status': 'available',
+        volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
+                                        'provider_location': '', 'size': 1,
                                         'attach_status': 'attached'})
         req = webob.Request.blank('/v2/fake/volumes/%s/action' % volume['id'])
         req.method = 'POST'
@@ -177,7 +178,8 @@ class AdminActionsTest(test.TestCase):
         # admin context
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
-        volume = db.volume_create(ctx, {'status': 'available',
+        volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
+                                        'provider_location': '', 'size': 1,
                                         'attach_status': 'detached'})
         req = webob.Request.blank('/v2/fake/volumes/%s/action' % volume['id'])
         req.method = 'POST'
@@ -200,7 +202,8 @@ class AdminActionsTest(test.TestCase):
         # admin context
         ctx = context.RequestContext('admin', 'fake', True)
         # snapshot in 'error_deleting'
-        volume = db.volume_create(ctx, {})
+        volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
+                                        'provider_location': '', 'size': 1})
         snapshot = db.snapshot_create(ctx, {'status': 'error_deleting',
                                             'volume_id': volume['id']})
         req = webob.Request.blank('/v2/fake/snapshots/%s/action' %
@@ -222,7 +225,8 @@ class AdminActionsTest(test.TestCase):
         # admin context
         ctx = context.RequestContext('admin', 'fake', True)
         # snapshot in 'available'
-        volume = db.volume_create(ctx, {})
+        volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
+                                        'provider_location': '', 'size': 1})
         snapshot = db.snapshot_create(ctx, {'status': 'available',
                                             'volume_id': volume['id']})
         req = webob.Request.blank('/v2/fake/snapshots/%s/action' %
@@ -245,7 +249,7 @@ class AdminActionsTest(test.TestCase):
         # admin context
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is creating
-        volume = db.volume_create(ctx, {'status': 'creating'})
+        volume = db.volume_create(ctx, {'size': 1})
         req = webob.Request.blank('/v2/fake/volumes/%s/action' % volume['id'])
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
@@ -259,14 +263,11 @@ class AdminActionsTest(test.TestCase):
         self.assertRaises(exception.NotFound, db.volume_get, ctx, volume['id'])
 
     def test_force_delete_snapshot(self):
-        self.stubs.Set(os.path, 'exists', lambda x: True)
-        # admin context
         ctx = context.RequestContext('admin', 'fake', True)
-        # current status is creating
-        volume = db.volume_create(ctx, {'host': 'test'})
-        snapshot = db.snapshot_create(ctx, {'status': 'creating',
-                                            'volume_size': 1,
-                                            'volume_id': volume['id']})
+        snapshot = stubs.stub_snapshot(1, host='foo')
+        self.stubs.Set(db, 'volume_get', lambda x, y: snapshot)
+        self.stubs.Set(db, 'snapshot_get', lambda x, y: snapshot)
+        self.stubs.Set(volume_api.API, 'delete_snapshot', lambda *x, **y: True)
         path = '/v2/fake/snapshots/%s/action' % snapshot['id']
         req = webob.Request.blank(path)
         req.method = 'POST'
@@ -274,24 +275,15 @@ class AdminActionsTest(test.TestCase):
         req.body = jsonutils.dumps({'os-force_delete': {}})
         # attach admin context to request
         req.environ['cinder.context'] = ctx
-        # start service to handle rpc.cast for 'delete snapshot'
-        svc = self.start_service('volume', host='test')
-        # make request
         resp = req.get_response(app())
-        # request is accepted
         self.assertEqual(resp.status_int, 202)
-        # snapshot is deleted
-        self.assertRaises(exception.NotFound, db.snapshot_get, ctx,
-                          snapshot['id'])
-        # cleanup
-        svc.stop()
 
     def test_force_detach_instance_attached_volume(self):
         # admin context
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
         volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
-                                        'provider_location': ''})
+                                        'provider_location': '', 'size': 1})
         connector = {'initiator': 'iqn.2012-07.org.fake:01'}
         # start service to handle rpc messages for attach requests
         svc = self.start_service('volume', host='test')
@@ -303,7 +295,7 @@ class AdminActionsTest(test.TestCase):
         volume = db.volume_get(ctx, volume['id'])
         self.assertEqual(volume['status'], 'in-use')
         self.assertEqual(volume['instance_uuid'], stubs.FAKE_UUID)
-        self.assertEqual(volume['attached_host'], None)
+        self.assertIsNone(volume['attached_host'])
         self.assertEqual(volume['mountpoint'], mountpoint)
         self.assertEqual(volume['attach_status'], 'attached')
         admin_metadata = volume['volume_admin_metadata']
@@ -330,9 +322,9 @@ class AdminActionsTest(test.TestCase):
         volume = db.volume_get(ctx, volume['id'])
         # status changed to 'available'
         self.assertEqual(volume['status'], 'available')
-        self.assertEqual(volume['instance_uuid'], None)
-        self.assertEqual(volume['attached_host'], None)
-        self.assertEqual(volume['mountpoint'], None)
+        self.assertIsNone(volume['instance_uuid'])
+        self.assertIsNone(volume['attached_host'])
+        self.assertIsNone(volume['mountpoint'])
         self.assertEqual(volume['attach_status'], 'detached')
         admin_metadata = volume['volume_admin_metadata']
         self.assertEqual(len(admin_metadata), 1)
@@ -346,7 +338,7 @@ class AdminActionsTest(test.TestCase):
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
         volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
-                                        'provider_location': ''})
+                                        'provider_location': '', 'size': 1})
         connector = {'initiator': 'iqn.2012-07.org.fake:01'}
         # start service to handle rpc messages for attach requests
         svc = self.start_service('volume', host='test')
@@ -357,7 +349,7 @@ class AdminActionsTest(test.TestCase):
         # volume is attached
         volume = db.volume_get(ctx, volume['id'])
         self.assertEqual(volume['status'], 'in-use')
-        self.assertEqual(volume['instance_uuid'], None)
+        self.assertIsNone(volume['instance_uuid'])
         self.assertEqual(volume['attached_host'], host_name)
         self.assertEqual(volume['mountpoint'], mountpoint)
         self.assertEqual(volume['attach_status'], 'attached')
@@ -385,9 +377,9 @@ class AdminActionsTest(test.TestCase):
         volume = db.volume_get(ctx, volume['id'])
         # status changed to 'available'
         self.assertEqual(volume['status'], 'available')
-        self.assertEqual(volume['instance_uuid'], None)
-        self.assertEqual(volume['attached_host'], None)
-        self.assertEqual(volume['mountpoint'], None)
+        self.assertIsNone(volume['instance_uuid'])
+        self.assertIsNone(volume['attached_host'])
+        self.assertIsNone(volume['mountpoint'])
         self.assertEqual(volume['attach_status'], 'detached')
         admin_metadata = volume['volume_admin_metadata']
         self.assertEqual(len(admin_metadata), 1)
@@ -402,7 +394,7 @@ class AdminActionsTest(test.TestCase):
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
         volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
-                                        'provider_location': ''})
+                                        'provider_location': '', 'size': 1})
         connector = {'initiator': 'iqn.2012-07.org.fake:01'}
         # start service to handle rpc messages for attach requests
         svc = self.start_service('volume', host='test')
@@ -438,7 +430,7 @@ class AdminActionsTest(test.TestCase):
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
         volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
-                                        'provider_location': ''})
+                                        'provider_location': '', 'size': 1})
         connector = {'initiator': 'iqn.2012-07.org.fake:01'}
         # start service to handle rpc messages for attach requests
         svc = self.start_service('volume', host='test')
@@ -474,7 +466,7 @@ class AdminActionsTest(test.TestCase):
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
         volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
-                                        'provider_location': ''})
+                                        'provider_location': '', 'size': 1})
         connector = {}
         # start service to handle rpc messages for attach requests
         svc = self.start_service('volume', host='test')
@@ -489,7 +481,7 @@ class AdminActionsTest(test.TestCase):
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
         volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
-                                        'provider_location': ''})
+                                        'provider_location': '', 'size': 1})
         # start service to handle rpc messages for attach requests
         svc = self.start_service('volume', host='test')
         values = {'status': 'attaching',
@@ -513,7 +505,7 @@ class AdminActionsTest(test.TestCase):
         ctx = context.RequestContext('admin', 'fake', True)
         # current status is available
         volume = db.volume_create(ctx, {'status': 'available', 'host': 'test',
-                                        'provider_location': ''})
+                                        'provider_location': '', 'size': 1})
         # start service to handle rpc messages for attach requests
         svc = self.start_service('volume', host='test')
         values = {'status': 'attaching',
@@ -584,6 +576,23 @@ class AdminActionsTest(test.TestCase):
         volume = self._migrate_volume_prep()
         self._migrate_volume_exec(ctx, volume, host, expected_status)
 
+    def test_migrate_volume_without_host_parameter(self):
+        expected_status = 400
+        host = 'test3'
+        ctx = context.RequestContext('admin', 'fake', True)
+        volume = self._migrate_volume_prep()
+        # build request to migrate without host
+        req = webob.Request.blank('/v2/fake/volumes/%s/action' % volume['id'])
+        req.method = 'POST'
+        req.headers['content-type'] = 'application/json'
+        body = {'os-migrate_volume': {'host': host,
+                                      'force_host_copy': False}}
+        req.body = jsonutils.dumps(body)
+        req.environ['cinder.context'] = ctx
+        resp = req.get_response(app())
+        # verify status
+        self.assertEqual(resp.status_int, expected_status)
+
     def test_migrate_volume_host_no_exist(self):
         expected_status = 400
         host = 'test3'
@@ -632,13 +641,15 @@ class AdminActionsTest(test.TestCase):
                                   force_host_copy=1)
 
     def _migrate_volume_comp_exec(self, ctx, volume, new_volume, error,
-                                  expected_status, expected_id):
-        admin_ctx = context.get_admin_context()
+                                  expected_status, expected_id, no_body=False):
         req = webob.Request.blank('/v2/fake/volumes/%s/action' % volume['id'])
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
-        body_dict = {'new_volume': new_volume['id'], 'error': error}
-        req.body = jsonutils.dumps({'os-migrate_volume_completion': body_dict})
+        body = {'new_volume': new_volume['id'], 'error': error}
+        if no_body:
+            req.body = jsonutils.dumps({'': body})
+        else:
+            req.body = jsonutils.dumps({'os-migrate_volume_completion': body})
         req.environ['cinder.context'] = ctx
         resp = req.get_response(app())
         resp_dict = ast.literal_eval(resp.body)
@@ -687,6 +698,16 @@ class AdminActionsTest(test.TestCase):
         volume = self._migrate_volume_comp_exec(ctx, volume1, volume2, False,
                                                 expected_status, expected_id)
 
+    def test_migrate_volume_comp_no_action(self):
+        admin_ctx = context.get_admin_context()
+        volume = db.volume_create(admin_ctx, {'id': 'fake1'})
+        new_volume = db.volume_create(admin_ctx, {'id': 'fake2'})
+        expected_status = 400
+        expected_id = None
+        ctx = context.RequestContext('fake', 'fake')
+        self._migrate_volume_comp_exec(ctx, volume, new_volume, False,
+                                       expected_status, expected_id, True)
+
     def test_migrate_volume_comp_from_nova(self):
         admin_ctx = context.get_admin_context()
         volume = db.volume_create(admin_ctx,
