@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2011 Zadara Storage Inc.
 # Copyright (c) 2011 OpenStack Foundation
 # Copyright 2011 University of Southern California
@@ -20,12 +18,13 @@
 from lxml import etree
 import webob
 
+import mock
+
 from cinder.api.contrib import types_extra_specs
 from cinder import exception
-from cinder.openstack.common.notifier import api as notifier_api
-from cinder.openstack.common.notifier import test_notifier
 from cinder import test
 from cinder.tests.api import fakes
+from cinder.tests import fake_notifier
 import cinder.wsgi
 
 
@@ -67,19 +66,14 @@ class VolumeTypesExtraSpecsTest(test.TestCase):
 
     def setUp(self):
         super(VolumeTypesExtraSpecsTest, self).setUp()
-        self.flags(connection_type='fake',
-                   host='fake',
-                   notification_driver=[test_notifier.__name__])
+        self.flags(host='fake')
         self.stubs.Set(cinder.db, 'volume_type_get', volume_type_get)
         self.api_path = '/v2/fake/os-volume-types/1/extra_specs'
         self.controller = types_extra_specs.VolumeTypeExtraSpecsController()
-        """to reset notifier drivers left over from other api/contrib tests"""
-        notifier_api._reset_drivers()
-        test_notifier.NOTIFICATIONS = []
 
-    def tearDown(self):
-        notifier_api._reset_drivers()
-        super(VolumeTypesExtraSpecsTest, self).tearDown()
+        """to reset notifier drivers left over from other api/contrib tests"""
+        fake_notifier.reset()
+        self.addCleanup(fake_notifier.reset)
 
     def test_index(self):
         self.stubs.Set(cinder.db, 'volume_type_extra_specs_get',
@@ -120,10 +114,10 @@ class VolumeTypesExtraSpecsTest(test.TestCase):
         self.stubs.Set(cinder.db, 'volume_type_extra_specs_delete',
                        delete_volume_type_extra_specs)
 
-        self.assertEqual(len(test_notifier.NOTIFICATIONS), 0)
+        self.assertEqual(len(fake_notifier.NOTIFICATIONS), 0)
         req = fakes.HTTPRequest.blank(self.api_path + '/key5')
         self.controller.delete(req, 1, 'key5')
-        self.assertEqual(len(test_notifier.NOTIFICATIONS), 1)
+        self.assertEqual(len(fake_notifier.NOTIFICATIONS), 1)
 
     def test_delete_not_found(self):
         self.stubs.Set(cinder.db, 'volume_type_extra_specs_delete',
@@ -139,23 +133,71 @@ class VolumeTypesExtraSpecsTest(test.TestCase):
                        return_create_volume_type_extra_specs)
         body = {"extra_specs": {"key1": "value1"}}
 
-        self.assertEqual(len(test_notifier.NOTIFICATIONS), 0)
+        self.assertEqual(len(fake_notifier.NOTIFICATIONS), 0)
         req = fakes.HTTPRequest.blank(self.api_path)
         res_dict = self.controller.create(req, 1, body)
-        self.assertEqual(len(test_notifier.NOTIFICATIONS), 1)
+        self.assertEqual(len(fake_notifier.NOTIFICATIONS), 1)
 
         self.assertEqual('value1', res_dict['extra_specs']['key1'])
 
+    @mock.patch.object(cinder.db, 'volume_type_extra_specs_update_or_create')
+    def test_create_key_allowed_chars(
+            self, volume_type_extra_specs_update_or_create):
+        mock_return_value = {"key1": "value1",
+                             "key2": "value2",
+                             "key3": "value3",
+                             "key4": "value4",
+                             "key5": "value5"}
+        volume_type_extra_specs_update_or_create.\
+            return_value = mock_return_value
+
+        body = {"extra_specs": {"other_alphanum.-_:": "value1"}}
+
+        self.assertEqual(len(fake_notifier.NOTIFICATIONS), 0)
+
+        req = fakes.HTTPRequest.blank(self.api_path)
+        res_dict = self.controller.create(req, 1, body)
+        self.assertEqual(len(fake_notifier.NOTIFICATIONS), 1)
+        self.assertEqual('value1',
+                         res_dict['extra_specs']['other_alphanum.-_:'])
+
+    @mock.patch.object(cinder.db, 'volume_type_extra_specs_update_or_create')
+    def test_create_too_many_keys_allowed_chars(
+            self, volume_type_extra_specs_update_or_create):
+        mock_return_value = {"key1": "value1",
+                             "key2": "value2",
+                             "key3": "value3",
+                             "key4": "value4",
+                             "key5": "value5"}
+        volume_type_extra_specs_update_or_create.\
+            return_value = mock_return_value
+
+        body = {"extra_specs": {"other_alphanum.-_:": "value1",
+                                "other2_alphanum.-_:": "value2",
+                                "other3_alphanum.-_:": "value3"}}
+
+        self.assertEqual(len(fake_notifier.NOTIFICATIONS), 0)
+
+        req = fakes.HTTPRequest.blank(self.api_path)
+        res_dict = self.controller.create(req, 1, body)
+        self.assertEqual(len(fake_notifier.NOTIFICATIONS), 1)
+        self.assertEqual('value1',
+                         res_dict['extra_specs']['other_alphanum.-_:'])
+        self.assertEqual('value2',
+                         res_dict['extra_specs']['other2_alphanum.-_:'])
+        self.assertEqual('value3',
+                         res_dict['extra_specs']['other3_alphanum.-_:'])
+
     def test_update_item(self):
         self.stubs.Set(cinder.db,
                        'volume_type_extra_specs_update_or_create',
                        return_create_volume_type_extra_specs)
         body = {"key1": "value1"}
 
-        self.assertEqual(len(test_notifier.NOTIFICATIONS), 0)
+        self.assertEqual(len(fake_notifier.NOTIFICATIONS), 0)
         req = fakes.HTTPRequest.blank(self.api_path + '/key1')
         res_dict = self.controller.update(req, 1, 'key1', body)
-        self.assertEqual(len(test_notifier.NOTIFICATIONS), 1)
+        self.assertEqual(len(fake_notifier.NOTIFICATIONS), 1)
 
         self.assertEqual('value1', res_dict['key1'])
 
@@ -195,6 +237,7 @@ class VolumeTypesExtraSpecsTest(test.TestCase):
     def _extra_specs_create_bad_body(self, body):
         req = fakes.HTTPRequest.blank('/v2/fake/types/1/extra_specs')
         req.method = 'POST'
+
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.create, req, '1', body)
 
@@ -209,6 +252,14 @@ class VolumeTypesExtraSpecsTest(test.TestCase):
         body = {'extra_specs': 'string'}
         self._extra_specs_create_bad_body(body=body)
 
+    def test_create_invalid_key(self):
+        body = {"extra_specs": {"ke/y1": "value1"}}
+        self._extra_specs_create_bad_body(body=body)
+
+    def test_create_invalid_too_many_key(self):
+        body = {"key1": "value1", "ke/y2": "value2", "key3": "value3"}
+        self._extra_specs_create_bad_body(body=body)
+
 
 class VolumeTypeExtraSpecsSerializerTest(test.TestCase):
     def test_index_create_serializer(self):
