@@ -1,4 +1,4 @@
-# Copyright (c) 2012 OpenStack, LLC
+# Copyright (c) 2012 OpenStack Foundation
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -12,15 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import StringIO
+from oslo.config import cfg
+import six
 import webob
 
 from cinder.api.middleware import sizelimit
-from cinder import flags
 from cinder import test
 
-FLAGS = flags.FLAGS
-MAX_REQUEST_BODY_SIZE = FLAGS.osapi_max_request_body_size
+
+CONF = cfg.CONF
+
+MAX_REQUEST_BODY_SIZE = CONF.osapi_max_request_body_size
 
 
 class TestLimitingReader(test.TestCase):
@@ -28,28 +30,28 @@ class TestLimitingReader(test.TestCase):
     def test_limiting_reader(self):
         BYTES = 1024
         bytes_read = 0
-        data = StringIO.StringIO("*" * BYTES)
+        data = six.StringIO("*" * BYTES)
         for chunk in sizelimit.LimitingReader(data, BYTES):
             bytes_read += len(chunk)
 
-        self.assertEquals(bytes_read, BYTES)
+        self.assertEqual(bytes_read, BYTES)
 
         bytes_read = 0
-        data = StringIO.StringIO("*" * BYTES)
+        data = six.StringIO("*" * BYTES)
         reader = sizelimit.LimitingReader(data, BYTES)
         byte = reader.read(1)
         while len(byte) != 0:
             bytes_read += 1
             byte = reader.read(1)
 
-        self.assertEquals(bytes_read, BYTES)
+        self.assertEqual(bytes_read, BYTES)
 
     def test_limiting_reader_fails(self):
         BYTES = 1024
 
         def _consume_all_iter():
             bytes_read = 0
-            data = StringIO.StringIO("*" * BYTES)
+            data = six.StringIO("*" * BYTES)
             for chunk in sizelimit.LimitingReader(data, BYTES - 1):
                 bytes_read += len(chunk)
 
@@ -58,7 +60,7 @@ class TestLimitingReader(test.TestCase):
 
         def _consume_all_read():
             bytes_read = 0
-            data = StringIO.StringIO("*" * BYTES)
+            data = six.StringIO("*" * BYTES)
             reader = sizelimit.LimitingReader(data, BYTES - 1)
             byte = reader.read(1)
             while len(byte) != 0:
