@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -25,7 +23,7 @@ class RequestTest(test.TestCase):
     def test_content_type_missing(self):
         request = wsgi.Request.blank('/tests/123', method='POST')
         request.body = "<body />"
-        self.assertEqual(None, request.get_content_type())
+        self.assertIsNone(request.get_content_type())
 
     def test_content_type_unsupported(self):
         request = wsgi.Request.blank('/tests/123', method='POST')
@@ -100,12 +98,12 @@ class RequestTest(test.TestCase):
         self.stubs.SmartSet(request.accept_language,
                             'best_match', fake_best_match)
 
-        self.assertEqual(request.best_match_language(), None)
+        self.assertIsNone(request.best_match_language())
         # If accept-language is not included or empty, match should be None
         request.headers = {'Accept-Language': ''}
-        self.assertEqual(request.best_match_language(), None)
+        self.assertIsNone(request.best_match_language())
         request.headers.pop('Accept-Language')
-        self.assertEqual(request.best_match_language(), None)
+        self.assertIsNone(request.best_match_language())
 
     def test_cache_and_retrieve_resources(self):
         request = wsgi.Request.blank('/foo')
@@ -247,6 +245,29 @@ class XMLDeserializerTest(test.TestCase):
         self.assertEqual(deserializer.deserialize(xml), as_dict)
 
 
+class MetadataXMLDeserializerTest(test.TestCase):
+    def test_xml_meta_parsing_special_character(self):
+        """Test that when a SaxParser splits a string containing special
+        characters into multiple childNodes there are no issues extracting
+        the text.
+        """
+        meta_xml_str = """
+            <metadata>
+                <meta key="key3">value&amp;3</meta>
+                <meta key="key2">value2</meta>
+                <meta key="key1">value1</meta>
+            </metadata>
+            """.strip()
+        meta_expected = {'key1': 'value1',
+                         'key2': 'value2',
+                         'key3': 'value&3'}
+        meta_deserializer = wsgi.MetadataXMLDeserializer()
+        document = wsgi.utils.safe_minidom_parse_string(meta_xml_str)
+        root_node = document.childNodes[0]
+        meta_extracted = meta_deserializer.extract_metadata(root_node)
+        self.assertEqual(meta_expected, meta_extracted)
+
+
 class ResourceTest(test.TestCase):
     def test_resource_call(self):
         class Controller(object):
@@ -386,7 +407,7 @@ class ResourceTest(test.TestCase):
         request.body = 'foo'
 
         content_type, body = resource.get_body(request)
-        self.assertEqual(content_type, None)
+        self.assertIsNone(content_type)
         self.assertEqual(body, '')
 
     def test_get_body_no_content_type(self):
@@ -401,7 +422,7 @@ class ResourceTest(test.TestCase):
         request.body = 'foo'
 
         content_type, body = resource.get_body(request)
-        self.assertEqual(content_type, None)
+        self.assertIsNone(content_type)
         self.assertEqual(body, '')
 
     def test_get_body_no_content_body(self):
@@ -417,7 +438,7 @@ class ResourceTest(test.TestCase):
         request.body = ''
 
         content_type, body = resource.get_body(request)
-        self.assertEqual(content_type, None)
+        self.assertIsNone(content_type)
         self.assertEqual(body, '')
 
     def test_get_body(self):
@@ -628,7 +649,7 @@ class ResourceTest(test.TestCase):
         extensions = [extension1, extension2]
         response, post = resource.pre_process_extensions(extensions, None, {})
         self.assertEqual(called, [])
-        self.assertEqual(response, None)
+        self.assertIsNone(response)
         self.assertEqual(list(post), [extension2, extension1])
 
     def test_pre_process_extensions_generator(self):
@@ -655,7 +676,7 @@ class ResourceTest(test.TestCase):
         response, post = resource.pre_process_extensions(extensions, None, {})
         post = list(post)
         self.assertEqual(called, ['pre1', 'pre2'])
-        self.assertEqual(response, None)
+        self.assertIsNone(response)
         self.assertEqual(len(post), 2)
         self.assertTrue(inspect.isgenerator(post[0]))
         self.assertTrue(inspect.isgenerator(post[1]))
@@ -712,7 +733,7 @@ class ResourceTest(test.TestCase):
         response = resource.post_process_extensions([extension2, extension1],
                                                     None, None, {})
         self.assertEqual(called, [2, 1])
-        self.assertEqual(response, None)
+        self.assertIsNone(response)
 
     def test_post_process_extensions_regular_response(self):
         class Controller(object):
@@ -764,7 +785,7 @@ class ResourceTest(test.TestCase):
                                                     None, None, {})
 
         self.assertEqual(called, [2, 1])
-        self.assertEqual(response, None)
+        self.assertIsNone(response)
 
     def test_post_process_extensions_generator_response(self):
         class Controller(object):
