@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -16,6 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import os
 
 from oslo.config import cfg
 
@@ -25,8 +24,11 @@ CONF = cfg.CONF
 CONF.import_opt('iscsi_num_targets', 'cinder.volume.drivers.lvm')
 CONF.import_opt('policy_file', 'cinder.policy')
 CONF.import_opt('volume_driver', 'cinder.volume.manager')
-CONF.import_opt('xiv_ds8k_proxy', 'cinder.volume.drivers.xiv_ds8k')
+CONF.import_opt('xiv_ds8k_proxy',
+                'cinder.volume.drivers.ibm.xiv_ds8k')
 CONF.import_opt('backup_driver', 'cinder.backup.manager')
+CONF.import_opt('fixed_key', 'cinder.keymgr.conf_key_mgr', group='keymgr')
+CONF.import_opt('scheduler_driver', 'cinder.scheduler.manager')
 
 def_vol_type = 'fake_vol_type'
 
@@ -36,18 +38,18 @@ def set_defaults(conf):
     conf.set_default('volume_driver',
                      'cinder.tests.fake_driver.FakeISCSIDriver')
     conf.set_default('iscsi_helper', 'fake')
-    conf.set_default('connection_type', 'fake')
     conf.set_default('fake_rabbit', True)
     conf.set_default('rpc_backend', 'cinder.openstack.common.rpc.impl_fake')
     conf.set_default('iscsi_num_targets', 8)
-    conf.set_default('verbose', True)
     conf.set_default('connection', 'sqlite://', group='database')
     conf.set_default('sqlite_synchronous', False)
     conf.set_default('policy_file', 'cinder/tests/policy.json')
     conf.set_default(
         'xiv_ds8k_proxy',
-        'cinder.tests.test_xiv_ds8k.XIVDS8KFakeProxyDriver')
+        'cinder.tests.test_ibm_xiv_ds8k.XIVDS8KFakeProxyDriver')
     conf.set_default('backup_driver', 'cinder.tests.backup.fake_service')
-    # NOTE(joel-coffman): This option for the ConfKeyManager must be set or
-    # else the ConfKeyManager cannot be instantiated.
     conf.set_default('fixed_key', default='0' * 64, group='keymgr')
+    conf.set_default('scheduler_driver',
+                     'cinder.scheduler.filter_scheduler.FilterScheduler')
+    conf.set_default('state_path', os.path.abspath(
+        os.path.join(os.path.dirname(__file__), '..', '..')))
