@@ -17,7 +17,6 @@
 
 from cinder import context
 from cinder import db
-from cinder import exception
 from cinder import test
 from cinder.tests import utils as testutils
 
@@ -50,4 +49,4 @@ class FinishVolumeMigrationTestCase(test.TestCase):
         self.assertEqual(src_volume['name'], expected_name)
         self.assertEqual(src_volume['host'], 'dest')
         self.assertEqual(src_volume['status'], 'available')
-        self.assertEqual(src_volume['migration_status'], None)
+        self.assertIsNone(src_volume['migration_status'])
