@@ -16,15 +16,15 @@
 Tests For HostManager
 """
 
+import mock
+
 from oslo.config import cfg
 
-from cinder import db
 from cinder import exception
 from cinder.openstack.common.scheduler import filters
 from cinder.openstack.common import timeutils
 from cinder.scheduler import host_manager
 from cinder import test
-from cinder.tests.scheduler import fakes
 
 
 CONF = cfg.CONF
@@ -41,7 +41,7 @@ class FakeFilterClass2(filters.BaseHostFilter):
 
 
 class HostManagerTestCase(test.TestCase):
-    """Test case for HostManager class"""
+    """Test case for HostManager class."""
 
     def setUp(self):
         super(HostManagerTestCase, self).setUp()
@@ -66,53 +66,35 @@ class HostManagerTestCase(test.TestCase):
         self.assertEqual(len(filter_classes), 1)
         self.assertEqual(filter_classes[0].__name__, 'FakeFilterClass2')
 
-    def _mock_get_filtered_hosts(self, info, specified_filters=None):
-        self.mox.StubOutWithMock(self.host_manager, '_choose_host_filters')
+    @mock.patch('cinder.scheduler.host_manager.HostManager.'
+                '_choose_host_filters')
+    def test_get_filtered_hosts(self, _mock_choose_host_filters):
+        filter_class = FakeFilterClass1
+        mock_func = mock.Mock()
+        mock_func.return_value = True
+        filter_class._filter_one = mock_func
+        _mock_choose_host_filters.return_value = [filter_class]
 
-        info['got_objs'] = []
-        info['got_fprops'] = []
-
-        def fake_filter_one(_self, obj, filter_props):
-            info['got_objs'].append(obj)
-            info['got_fprops'].append(filter_props)
-            return True
-
-        self.stubs.Set(FakeFilterClass1, '_filter_one', fake_filter_one)
-        self.host_manager._choose_host_filters(specified_filters).AndReturn(
-            [FakeFilterClass1])
-
-    def _verify_result(self, info, result):
-        for x in info['got_fprops']:
-            self.assertEqual(x, info['expected_fprops'])
-        self.assertEqual(set(info['expected_objs']), set(info['got_objs']))
-        self.assertEqual(set(result), set(info['got_objs']))
-
-    def test_get_filtered_hosts(self):
         fake_properties = {'moo': 1, 'cow': 2}
+        expected = []
+        for fake_host in self.fake_hosts:
+            expected.append(mock.call(fake_host, fake_properties))
 
-        info = {'expected_objs': self.fake_hosts,
-                'expected_fprops': fake_properties}
-
-        self._mock_get_filtered_hosts(info)
-
-        self.mox.ReplayAll()
         result = self.host_manager.get_filtered_hosts(self.fake_hosts,
                                                       fake_properties)
-        self._verify_result(info, result)
+        self.assertEqual(expected, mock_func.call_args_list)
+        self.assertEqual(set(result), set(self.fake_hosts))
 
-    def test_update_service_capabilities(self):
+    @mock.patch('cinder.openstack.common.timeutils.utcnow')
+    def test_update_service_capabilities(self, _mock_utcnow):
         service_states = self.host_manager.service_states
         self.assertDictMatch(service_states, {})
-        self.mox.StubOutWithMock(timeutils, 'utcnow')
-        timeutils.utcnow().AndReturn(31337)
-        timeutils.utcnow().AndReturn(31338)
-        timeutils.utcnow().AndReturn(31339)
+        _mock_utcnow.side_effect = [31337, 31338, 31339]
 
         host1_volume_capabs = dict(free_capacity_gb=4321, timestamp=1)
         host2_volume_capabs = dict(free_capacity_gb=5432, timestamp=1)
         host3_volume_capabs = dict(free_capacity_gb=6543, timestamp=1)
 
-        self.mox.ReplayAll()
         service_name = 'volume'
         self.host_manager.update_service_capabilities(service_name, 'host1',
                                                       host1_volume_capabs)
@@ -135,14 +117,13 @@ class HostManagerTestCase(test.TestCase):
                     'host3': host3_volume_capabs}
         self.assertDictMatch(service_states, expected)
 
-    def test_get_all_host_states(self):
+    @mock.patch('cinder.db.service_get_all_by_topic')
+    @mock.patch('cinder.utils.service_is_up')
+    def test_get_all_host_states(self, _mock_service_is_up,
+                                 _mock_service_get_all_by_topic):
         context = 'fake_context'
         topic = CONF.volume_topic
 
-        self.mox.StubOutWithMock(db, 'service_get_all_by_topic')
-        self.mox.StubOutWithMock(host_manager.LOG, 'warn')
-        self.mox.StubOutWithMock(host_manager.utils, 'service_is_up')
-
         services = [
             dict(id=1, host='host1', topic='volume', disabled=False,
                  availability_zone='zone1', updated_at=timeutils.utcnow()),
@@ -157,44 +138,51 @@ class HostManagerTestCase(test.TestCase):
                  availability_zone='zone4', updated_at=timeutils.utcnow()),
         ]
 
-        db.service_get_all_by_topic(context, topic).AndReturn(services)
-        host_manager.utils.service_is_up(services[0]).AndReturn(True)
-        host_manager.utils.service_is_up(services[1]).AndReturn(True)
-        host_manager.utils.service_is_up(services[2]).AndReturn(True)
-        host_manager.utils.service_is_up(services[3]).AndReturn(True)
-        host_manager.utils.service_is_up(services[4]).AndReturn(True)
-        # Disabled service
-        host_manager.LOG.warn("volume service is down or disabled. "
-                              "(host: host5)")
+        # First test: service_is_up is always True, host5 is disabled
+        _mock_service_get_all_by_topic.return_value = services
+        _mock_service_is_up.return_value = True
+        _mock_warning = mock.Mock()
+        host_manager.LOG.warn = _mock_warning
 
-        db.service_get_all_by_topic(context, topic).AndReturn(services)
-        host_manager.utils.service_is_up(services[0]).AndReturn(True)
-        host_manager.utils.service_is_up(services[1]).AndReturn(True)
-        host_manager.utils.service_is_up(services[2]).AndReturn(True)
-        host_manager.utils.service_is_up(services[3]).AndReturn(False)
-        # Stopped service
-        host_manager.LOG.warn("volume service is down or disabled. "
-                              "(host: host4)")
-        host_manager.utils.service_is_up(services[4]).AndReturn(True)
-        # Disabled service
-        host_manager.LOG.warn("volume service is down or disabled. "
-                              "(host: host5)")
-
-        self.mox.ReplayAll()
+        # Get all states, make sure host5 is reported as down/disabled
         self.host_manager.get_all_host_states(context)
-        host_state_map = self.host_manager.host_state_map
+        _mock_service_get_all_by_topic.assert_called_with(context, topic)
+        expected = []
+        for service in services:
+            expected.append(mock.call(service))
+        self.assertEqual(expected, _mock_service_is_up.call_args_list)
+        _mock_warning.assert_called_with("volume service is down or disabled. "
+                                         "(host: host5)")
 
+        # Get host_state_map and make sure we have the first 4 hosts
+        host_state_map = self.host_manager.host_state_map
         self.assertEqual(len(host_state_map), 4)
-        # Check that service is up
         for i in xrange(4):
             volume_node = services[i]
             host = volume_node['host']
-            self.assertEqual(host_state_map[host].service,
-                             volume_node)
+            self.assertEqual(host_state_map[host].service, volume_node)
 
+        # Second test: Now service_is_up returns False for host4
+        _mock_service_is_up.reset_mock()
+        _mock_service_is_up.side_effect = [True, True, True, False, True]
+        _mock_service_get_all_by_topic.reset_mock()
+        _mock_warning.reset_mock()
+
+        # Get all states, make sure hosts 4 and 5 is reported as down/disabled
         self.host_manager.get_all_host_states(context)
-        host_state_map = self.host_manager.host_state_map
+        _mock_service_get_all_by_topic.assert_called_with(context, topic)
+        expected = []
+        for service in services:
+            expected.append(mock.call(service))
+        self.assertEqual(expected, _mock_service_is_up.call_args_list)
+        expected = []
+        for num in ['4', '5']:
+            expected.append(mock.call("volume service is down or disabled. "
+                                      "(host: host" + num + ")"))
+        self.assertEqual(expected, _mock_warning.call_args_list)
 
+        # Get host_state_map and make sure we have the first 4 hosts
+        host_state_map = self.host_manager.host_state_map
         self.assertEqual(len(host_state_map), 3)
         for i in xrange(3):
             volume_node = services[i]
@@ -204,11 +192,11 @@ class HostManagerTestCase(test.TestCase):
 
 
 class HostStateTestCase(test.TestCase):
-    """Test case for HostState class"""
+    """Test case for HostState class."""
 
     def test_update_from_volume_capability(self):
         fake_host = host_manager.HostState('host1')
-        self.assertEqual(fake_host.free_capacity_gb, None)
+        self.assertIsNone(fake_host.free_capacity_gb)
 
         volume_capability = {'total_capacity_gb': 1024,
                              'free_capacity_gb': 512,
@@ -220,7 +208,7 @@ class HostStateTestCase(test.TestCase):
 
     def test_update_from_volume_infinite_capability(self):
         fake_host = host_manager.HostState('host1')
-        self.assertEqual(fake_host.free_capacity_gb, None)
+        self.assertIsNone(fake_host.free_capacity_gb)
 
         volume_capability = {'total_capacity_gb': 'infinite',
                              'free_capacity_gb': 'infinite',
@@ -233,7 +221,7 @@ class HostStateTestCase(test.TestCase):
 
     def test_update_from_volume_unknown_capability(self):
         fake_host = host_manager.HostState('host1')
-        self.assertEqual(fake_host.free_capacity_gb, None)
+        self.assertIsNone(fake_host.free_capacity_gb)
 
         volume_capability = {'total_capacity_gb': 'infinite',
                              'free_capacity_gb': 'unknown',
