@@ -168,6 +168,16 @@ class DellEQLSanISCSIDriverTestCase(test.TestCase):
         self.mox.ReplayAll()
         self.driver.delete_snapshot(snapshot)
 
+    def test_extend_volume(self):
+        new_size = '200'
+        self.driver._eql_execute = self.mox.\
+            CreateMock(self.driver._eql_execute)
+        volume = {'name': self.volume_name, 'size': 100}
+        self.driver._eql_execute('volume', 'select', volume['name'],
+                                 'size', "%sG" % new_size)
+        self.mox.ReplayAll()
+        self.driver.extend_volume(volume, new_size)
+
     def test_initialize_connection(self):
         self.driver._eql_execute = self.mox.\
             CreateMock(self.driver._eql_execute)
@@ -177,7 +187,7 @@ class DellEQLSanISCSIDriverTestCase(test.TestCase):
         self.driver._eql_execute('volume', 'select', volume['name'], 'access',
                                  'create', 'initiator',
                                  self.connector['initiator'],
-                                 'authmethod chap',
+                                 'authmethod', 'chap',
                                  'username',
                                  self.configuration.eqlx_chap_login)
         self.mox.ReplayAll()
@@ -207,17 +217,29 @@ class DellEQLSanISCSIDriverTestCase(test.TestCase):
         self.driver.do_setup(self._context)
         self.assertEqual(fake_group_ip, self.driver._group_ip)
 
-    def test_update_volume_status(self):
+    def test_update_volume_stats(self):
         self.driver._eql_execute = self.mox.\
             CreateMock(self.driver._eql_execute)
         self.driver._eql_execute('pool', 'select',
                                  self.configuration.eqlx_pool, 'show').\
             AndReturn(['TotalCapacity: 111GB', 'FreeSpace: 11GB'])
         self.mox.ReplayAll()
-        self.driver._update_volume_status()
+        self.driver._update_volume_stats()
         self.assertEqual(self.driver._stats['total_capacity_gb'], 111.0)
         self.assertEqual(self.driver._stats['free_capacity_gb'], 11.0)
 
+    def test_get_volume_stats(self):
+        self.driver._eql_execute = self.mox.\
+            CreateMock(self.driver._eql_execute)
+        self.driver._eql_execute('pool', 'select',
+                                 self.configuration.eqlx_pool, 'show').\
+            AndReturn(['TotalCapacity: 111GB', 'FreeSpace: 11GB'])
+        self.mox.ReplayAll()
+        stats = self.driver.get_volume_stats(refresh=True)
+        self.assertEqual(stats['total_capacity_gb'], float('111.0'))
+        self.assertEqual(stats['free_capacity_gb'], float('11.0'))
+        self.assertEqual(stats['vendor_name'], 'Dell')
+
     def test_get_space_in_gb(self):
         self.assertEqual(self.driver._get_space_in_gb('123.0GB'), 123.0)
         self.assertEqual(self.driver._get_space_in_gb('123.0TB'), 123.0 * 1024)
