@@ -1,4 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
 # Copyright (c) 2013 Huawei Technologies Co., Ltd.
 # Copyright (c) 2013 OpenStack Foundation
@@ -30,7 +29,6 @@ from xml.dom.minidom import Document
 
 from cinder import exception
 from cinder import test
-from cinder import utils
 from cinder.volume import configuration as conf
 from cinder.volume.drivers.huawei import huawei_hvs
 from cinder.volume.drivers.huawei import rest_common
@@ -61,7 +59,10 @@ test_snap = {'name': 'volume-21ec7341-9256-497b-97d9-ef48edcf0635',
 FakeConnector = {'initiator': 'iqn.1993-08.debian:01:ec2bff7ac3a3',
                  'wwpns': ['10000090fa0d6754'],
                  'wwnns': ['10000090fa0d6755'],
-                 'host': 'fakehost'}
+                 'host': 'fakehost',
+                 'ip': '10.10.0.1'}
+
+volume_size = 3
 
 
 def Fake_sleep(time):
@@ -101,7 +102,10 @@ class FakeHVSCommon(rest_common.HVSCommon):
         return params
 
     def _change_file_mode(self, filepath):
-        utils.execute('chmod', '777', filepath)
+        # NOTE(flaper87): Changing file permissions is
+        # not needed since we're using a tempfile created
+        # within this test.
+        pass
 
     def call(self, url=False, data=None, method=None):
 
@@ -465,6 +469,10 @@ class FakeHVSCommon(rest_common.HVSCommon):
             if url == "ioclass/0":
                 data = """{"error":{"code":0}}"""
 
+            if url == "lun/expand":
+                data = """{"error":{"code":0}}"""
+                self.lun_id = '0'
+
         else:
             data = """{"error":{"code":31755596}}"""
 
@@ -503,6 +511,7 @@ class HVSRESTiSCSIDriverTestCase(test.TestCase):
         self.configuration.append_config_values(mox.IgnoreArg())
 
         self.stubs.Set(time, 'sleep', Fake_sleep)
+        #self.stubs.Set(greenthread, 'sleep', Fake_sleep)
 
         self.driver = FakeHVSiSCSIStorage(configuration=self.configuration)
         self.driver.do_setup({})
@@ -516,7 +525,7 @@ class HVSRESTiSCSIDriverTestCase(test.TestCase):
 
     def test_log_in_success(self):
         deviceid = self.driver.common.login()
-        self.assertNotEqual(deviceid, None)
+        self.assertIsNotNone(deviceid)
 
     def test_log_out_success(self):
         self.driver.common.login()
@@ -527,6 +536,11 @@ class HVSRESTiSCSIDriverTestCase(test.TestCase):
         self.driver.create_volume(test_volume)
         self.assertEqual(self.driver.common.lun_id, "0")
 
+    def test_extend_volume_success(self):
+        self.driver.common.login()
+        self.driver.extend_volume(test_volume, volume_size)
+        self.assertEqual(self.driver.common.lun_id, "0")
+
     def test_create_snapshot_success(self):
         self.driver.common.login()
         self.driver.create_snapshot(test_volume)
@@ -535,12 +549,12 @@ class HVSRESTiSCSIDriverTestCase(test.TestCase):
     def test_delete_volume_success(self):
         self.driver.common.login()
         self.driver.delete_volume(test_volume)
-        self.assertEqual(self.driver.common.lun_id, None)
+        self.assertIsNone(self.driver.common.lun_id)
 
     def test_delete_snapshot_success(self):
         self.driver.common.login()
         self.driver.delete_snapshot(test_snap)
-        self.assertEqual(self.driver.common.snapshot_id, None)
+        self.assertIsNone(self.driver.common.snapshot_id)
 
     def test_colone_volume_success(self):
         self.driver.common.login()
@@ -577,7 +591,7 @@ class HVSRESTiSCSIDriverTestCase(test.TestCase):
     def test_get_volume_stats(self):
         self.driver.common.login()
         status = self.driver.get_volume_stats()
-        self.assertNotEqual(status['free_capacity_gb'], None)
+        self.assertIsNotNone(status['free_capacity_gb'])
 
     def test_create_snapshot_fail(self):
         self.driver.common.login()
@@ -624,10 +638,10 @@ class HVSRESTiSCSIDriverTestCase(test.TestCase):
         product.appendChild(product_text)
         storage.appendChild(product)
 
-        protocal = doc.createElement('Protocol')
-        protocal_text = doc.createTextNode('iSCSI')
-        protocal.appendChild(protocal_text)
-        storage.appendChild(protocal)
+        protocol = doc.createElement('Protocol')
+        protocol_text = doc.createTextNode('iSCSI')
+        protocol.appendChild(protocol_text)
+        storage.appendChild(protocol)
 
         username = doc.createElement('UserName')
         username_text = doc.createTextNode('admin')
@@ -705,13 +719,18 @@ class HVSRESTFCDriverTestCase(test.TestCase):
 
     def test_log_in_Success(self):
         deviceid = self.driver.common.login()
-        self.assertNotEqual(deviceid, None)
+        self.assertIsNotNone(deviceid)
 
     def test_create_volume_success(self):
         self.driver.common.login()
         self.driver.create_volume(test_volume)
         self.assertEqual(self.driver.common.lun_id, "0")
 
+    def test_extend_volume_success(self):
+        self.driver.common.login()
+        self.driver.extend_volume(test_volume, volume_size)
+        self.assertEqual(self.driver.common.lun_id, "0")
+
     def test_create_snapshot_success(self):
         self.driver.common.login()
         self.driver.create_snapshot(test_volume)
@@ -720,12 +739,12 @@ class HVSRESTFCDriverTestCase(test.TestCase):
     def test_delete_volume_success(self):
         self.driver.common.login()
         self.driver.delete_volume(test_volume)
-        self.assertEqual(self.driver.common.lun_id, None)
+        self.assertIsNone(self.driver.common.lun_id)
 
     def test_delete_snapshot_success(self):
         self.driver.common.login()
         self.driver.delete_snapshot(test_snap)
-        self.assertEqual(self.driver.common.snapshot_id, None)
+        self.assertIsNone(self.driver.common.snapshot_id)
 
     def test_colone_volume_success(self):
         self.driver.common.login()
@@ -762,7 +781,7 @@ class HVSRESTFCDriverTestCase(test.TestCase):
     def test_get_volume_stats(self):
         self.driver.common.login()
         status = self.driver.get_volume_stats()
-        self.assertNotEqual(status['free_capacity_gb'], None)
+        self.assertIsNotNone(status['free_capacity_gb'])
 
     def test_create_snapshot_fail(self):
         self.driver.common.login()
@@ -802,10 +821,10 @@ class HVSRESTFCDriverTestCase(test.TestCase):
         product.appendChild(product_text)
         storage.appendChild(product)
 
-        protocal = doc.createElement('Protocol')
-        protocal_text = doc.createTextNode('FC')
-        protocal.appendChild(protocal_text)
-        storage.appendChild(protocal)
+        protocol = doc.createElement('Protocol')
+        protocol_text = doc.createTextNode('FC')
+        protocol.appendChild(protocol_text)
+        storage.appendChild(protocol)
 
         username = doc.createElement('UserName')
         username_text = doc.createTextNode('admin')
