@@ -1,4 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
@@ -19,6 +18,7 @@
 
 import datetime
 
+import mock
 from oslo.config import cfg
 
 from cinder import context
@@ -26,7 +26,6 @@ from cinder import db
 from cinder.db.sqlalchemy import api as sqa_api
 from cinder.db.sqlalchemy import models as sqa_models
 from cinder import exception
-from cinder.openstack.common import rpc
 from cinder.openstack.common import timeutils
 from cinder import quota
 from cinder import test
@@ -55,12 +54,11 @@ class QuotaIntegrationTestCase(test.TestCase):
         self.context = context.RequestContext(self.user_id,
                                               self.project_id,
                                               is_admin=True)
-        orig_rpc_call = rpc.call
 
-        def rpc_call_wrapper(context, topic, msg, timeout=None):
-            return orig_rpc_call(context, topic, msg)
-
-        self.stubs.Set(rpc, 'call', rpc_call_wrapper)
+        # Destroy the 'default' quota_class in the database to avoid
+        # conflicts with the test cases here that are setting up their own
+        # defaults.
+        db.quota_class_destroy_all_by_name(self.context, 'default')
 
     def tearDown(self):
         db.volume_type_destroy(context.get_admin_context(),
@@ -166,7 +164,7 @@ class QuotaIntegrationTestCase(test.TestCase):
         # Make sure no reservation was created for snapshot gigabytes.
         reservations = db.reservation_get_all_by_project(self.context,
                                                          self.project_id)
-        self.assertEqual(reservations.get('gigabytes'), None)
+        self.assertIsNone(reservations.get('gigabytes'))
 
         # Make sure the snapshot volume_size isn't included in usage.
         vol_ref2 = volume.API().create(self.context, 10, '', '')
@@ -277,7 +275,7 @@ class BaseResourceTestCase(test.TestCase):
         resource = quota.BaseResource('test_resource')
 
         self.assertEqual(resource.name, 'test_resource')
-        self.assertEqual(resource.flag, None)
+        self.assertIsNone(resource.flag)
         self.assertEqual(resource.default, -1)
 
     def test_with_flag(self):
@@ -371,7 +369,7 @@ class VolumeTypeResourceTestCase(test.TestCase):
         resource = quota.VolumeTypeResource('volumes', volume)
 
         self.assertEqual(resource.name, 'volumes_%s' % volume_type_name)
-        self.assertEqual(resource.flag, None)
+        self.assertIsNone(resource.flag)
         self.assertEqual(resource.default, -1)
 
 
@@ -733,11 +731,10 @@ class DbQuotaDriverTestCase(test.TestCase):
 
         self.calls = []
 
-        timeutils.set_time_override()
-
-    def tearDown(self):
-        timeutils.clear_time_override()
-        super(DbQuotaDriverTestCase, self).tearDown()
+        patcher = mock.patch.object(timeutils, 'utcnow')
+        self.addCleanup(patcher.stop)
+        self.mock_utcnow = patcher.start()
+        self.mock_utcnow.return_value = datetime.datetime.utcnow()
 
     def test_get_defaults(self):
         # Use our pre-defined resources
@@ -1159,7 +1156,10 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
         self.stubs.Set(sqa_api, '_quota_usage_create', fake_quota_usage_create)
         self.stubs.Set(sqa_api, '_reservation_create', fake_reservation_create)
 
-        timeutils.set_time_override()
+        patcher = mock.patch.object(timeutils, 'utcnow')
+        self.addCleanup(patcher.stop)
+        self.mock_utcnow = patcher.start()
+        self.mock_utcnow.return_value = datetime.datetime.utcnow()
 
     def _make_quota_usage(self, project_id, resource, in_use, reserved,
                           until_refresh, created_at, updated_at):
