@@ -1,4 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
@@ -21,6 +20,7 @@ Unit Tests for remote procedure calls using queue
 """
 
 
+import mock
 import mox
 from oslo.config import cfg
 
@@ -49,7 +49,7 @@ CONF.register_opts(test_service_opts)
 
 
 class FakeManager(manager.Manager):
-    """Fake manager for tests"""
+    """Fake manager for tests."""
     def __init__(self, host=None,
                  db_driver=None, service_name=None):
         super(FakeManager, self).__init__(host=host,
@@ -65,7 +65,7 @@ class ExtendedService(service.Service):
 
 
 class ServiceManagerTestCase(test.TestCase):
-    """Test cases for Services"""
+    """Test cases for Services."""
 
     def test_message_gets_to_manager(self):
         serv = service.Service('test',
@@ -109,7 +109,7 @@ class ServiceFlagsTestCase(test.TestCase):
 
 
 class ServiceTestCase(test.TestCase):
-    """Test cases for Services"""
+    """Test cases for Services."""
 
     def setUp(self):
         super(ServiceTestCase, self).setUp()
@@ -196,6 +196,13 @@ class ServiceTestCase(test.TestCase):
 
         self.assertFalse(serv.model_disconnected)
 
+    def test_service_with_long_report_interval(self):
+        CONF.set_override('service_down_time', 10)
+        CONF.set_override('report_interval', 10)
+        service.Service.create(binary="test_service",
+                               manager="cinder.tests.test_service.FakeManager")
+        self.assertEqual(CONF.service_down_time, 25)
+
 
 class TestWSGIService(test.TestCase):
 
@@ -211,16 +218,25 @@ class TestWSGIService(test.TestCase):
         test_service.stop()
 
 
-class TestLauncher(test.TestCase):
+class OSCompatibilityTestCase(test.TestCase):
+    def _test_service_launcher(self, fake_os):
+        # Note(lpetrut): The cinder-volume service needs to be spawned
+        # differently on Windows due to an eventlet bug. For this reason,
+        # we must check the process launcher used.
+        fake_process_launcher = mock.MagicMock()
+        with mock.patch('os.name', fake_os):
+            with mock.patch('cinder.service.process_launcher',
+                            fake_process_launcher):
+                launcher = service.get_launcher()
+                if fake_os == 'nt':
+                    self.assertEqual(type(launcher),
+                                     service.Launcher)
+                else:
+                    self.assertEqual(launcher,
+                                     fake_process_launcher())
 
-    def setUp(self):
-        super(TestLauncher, self).setUp()
-        self.stubs.Set(wsgi.Loader, "load_app", mox.MockAnything())
-        self.service = service.WSGIService("test_service")
+    def test_process_launcher_on_windows(self):
+        self._test_service_launcher('nt')
 
-    def test_launch_app(self):
-        self.assertEqual(0, self.service.port)
-        launcher = service.Launcher()
-        launcher.launch_server(self.service)
-        self.assertEqual(0, self.service.port)
-        launcher.stop()
+    def test_process_launcher_on_linux(self):
+        self._test_service_launcher('posix')
