@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2011 Zadara Storage Inc.
 # Copyright (c) 2011 OpenStack Foundation
 # Copyright 2011 University of Southern California
@@ -28,10 +26,7 @@ class VolumeGlanceMetadataTestCase(test.TestCase):
 
     def setUp(self):
         super(VolumeGlanceMetadataTestCase, self).setUp()
-        self.context = context.get_admin_context()
-
-    def tearDown(self):
-        super(VolumeGlanceMetadataTestCase, self).tearDown()
+        self.ctxt = context.get_admin_context()
 
     def test_vol_glance_metadata_bad_vol_id(self):
         ctxt = context.get_admin_context()
@@ -53,6 +48,9 @@ class VolumeGlanceMetadataTestCase(test.TestCase):
         vol_metadata = db.volume_glance_metadata_create(ctxt, 2,
                                                         'key2',
                                                         'value2')
+        vol_metadata = db.volume_glance_metadata_create(ctxt, 2,
+                                                        'key3',
+                                                        123)
 
         expected_metadata_1 = {'volume_id': '1',
                                'key': 'key1',
@@ -68,10 +66,13 @@ class VolumeGlanceMetadataTestCase(test.TestCase):
                                 'value': 'value1'},
                                {'volume_id': '2',
                                 'key': 'key2',
-                                'value': 'value2'})
+                                'value': 'value2'},
+                               {'volume_id': '2',
+                                'key': 'key3',
+                                'value': '123'})
 
         metadata = db.volume_glance_metadata_get(ctxt, 2)
-        self.assertEqual(len(metadata), 2)
+        self.assertEqual(len(metadata), 3)
         for expected, meta in zip(expected_metadata_2, metadata):
             for key, value in expected.iteritems():
                 self.assertEqual(meta[key], value)
@@ -131,7 +132,7 @@ class VolumeGlanceMetadataTestCase(test.TestCase):
             for (key, value) in expected_meta.items():
                 self.assertEqual(meta[key], value)
 
-    def test_vol_glance_metadata_copy_to_volume(self):
+    def test_vol_glance_metadata_copy_from_volume_to_volume(self):
         ctxt = context.get_admin_context()
         db.volume_create(ctxt, {'id': 1})
         db.volume_create(ctxt, {'id': 100, 'source_volid': 1})
@@ -145,3 +146,23 @@ class VolumeGlanceMetadataTestCase(test.TestCase):
         for meta in db.volume_glance_metadata_get(ctxt, 100):
             for (key, value) in expected_meta.items():
                 self.assertEqual(meta[key], value)
+
+    def test_volume_glance_metadata_copy_to_volume(self):
+        vol1 = db.volume_create(self.ctxt, {})
+        vol2 = db.volume_create(self.ctxt, {})
+        db.volume_glance_metadata_create(self.ctxt, vol1['id'], 'm1', 'v1')
+        snapshot = db.snapshot_create(self.ctxt, {'volume_id': vol1['id']})
+        db.volume_glance_metadata_copy_to_snapshot(self.ctxt, snapshot['id'],
+                                                   vol1['id'])
+        db.volume_glance_metadata_copy_to_volume(self.ctxt, vol2['id'],
+                                                 snapshot['id'])
+        metadata = db.volume_glance_metadata_get(self.ctxt, vol2['id'])
+        metadata = dict([(m['key'], m['value']) for m in metadata])
+        self.assertEqual(metadata, {'m1': 'v1'})
+
+    def test_volume_snapshot_glance_metadata_get_nonexistent(self):
+        vol = db.volume_create(self.ctxt, {})
+        snapshot = db.snapshot_create(self.ctxt, {'volume_id': vol['id']})
+        self.assertRaises(exception.GlanceMetadataNotFound,
+                          db.volume_snapshot_glance_metadata_get,
+                          self.ctxt, snapshot['id'])
