@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012, Intel, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -17,27 +15,28 @@
 """
 Unit Tests for cinder.volume.rpcapi
 """
+import copy
 
+from oslo.config import cfg
 
 from cinder import context
 from cinder import db
-from cinder import flags
 from cinder.openstack.common import jsonutils
-from cinder.openstack.common import rpc
 from cinder import test
 from cinder.volume import rpcapi as volume_rpcapi
 
 
-FLAGS = flags.FLAGS
+CONF = cfg.CONF
 
 
 class VolumeRpcAPITestCase(test.TestCase):
 
     def setUp(self):
+        super(VolumeRpcAPITestCase, self).setUp()
         self.context = context.get_admin_context()
         vol = {}
         vol['host'] = 'fake_host'
-        vol['availability_zone'] = FLAGS.storage_availability_zone
+        vol['availability_zone'] = CONF.storage_availability_zone
         vol['status'] = "available"
         vol['attach_status'] = "detached"
         vol['metadata'] = {"test_key": "test_val"}
@@ -54,10 +53,10 @@ class VolumeRpcAPITestCase(test.TestCase):
         self.fake_volume = jsonutils.to_primitive(volume)
         self.fake_volume_metadata = volume["volume_metadata"]
         self.fake_snapshot = jsonutils.to_primitive(snapshot)
-        super(VolumeRpcAPITestCase, self).setUp()
+        self.fake_reservations = ["RESERVATION"]
 
     def test_serialized_volume_has_id(self):
-        self.assertTrue('id' in self.fake_volume)
+        self.assertIn('id', self.fake_volume)
 
     def _test_volume_api(self, method, rpc_method, **kwargs):
         ctxt = context.RequestContext('fake_user', 'fake_project')
@@ -70,50 +69,74 @@ class VolumeRpcAPITestCase(test.TestCase):
         rpcapi = rpcapi_class()
         expected_retval = 'foo' if method == 'call' else None
 
-        expected_version = kwargs.pop('version', rpcapi.BASE_RPC_API_VERSION)
+        target = {
+            "version": kwargs.pop('version', rpcapi.BASE_RPC_API_VERSION)
+        }
 
         if 'request_spec' in kwargs:
             spec = jsonutils.to_primitive(kwargs['request_spec'])
             kwargs['request_spec'] = spec
 
-        expected_msg = rpcapi.make_msg(method, **kwargs)
-        if 'volume' in expected_msg['args']:
-            volume = expected_msg['args']['volume']
-            del expected_msg['args']['volume']
-            expected_msg['args']['volume_id'] = volume['id']
-        if 'snapshot' in expected_msg['args']:
-            snapshot = expected_msg['args']['snapshot']
-            del expected_msg['args']['snapshot']
-            expected_msg['args']['snapshot_id'] = snapshot['id']
-        if 'host' in expected_msg['args']:
-            del expected_msg['args']['host']
-
-        expected_msg['version'] = expected_version
+        expected_msg = copy.deepcopy(kwargs)
+        if 'volume' in expected_msg:
+            volume = expected_msg['volume']
+            del expected_msg['volume']
+            expected_msg['volume_id'] = volume['id']
+        if 'snapshot' in expected_msg:
+            snapshot = expected_msg['snapshot']
+            del expected_msg['snapshot']
+            expected_msg['snapshot_id'] = snapshot['id']
+        if 'host' in expected_msg:
+            del expected_msg['host']
+        if 'dest_host' in expected_msg:
+            dest_host = expected_msg['dest_host']
+            dest_host_dict = {'host': dest_host.host,
+                              'capabilities': dest_host.capabilities}
+            del expected_msg['dest_host']
+            expected_msg['host'] = dest_host_dict
+        if 'new_volume' in expected_msg:
+            volume = expected_msg['new_volume']
+            del expected_msg['new_volume']
+            expected_msg['new_volume_id'] = volume['id']
 
         if 'host' in kwargs:
             host = kwargs['host']
         else:
             host = kwargs['volume']['host']
-        expected_topic = '%s.%s' % (FLAGS.volume_topic, host)
+
+        target['server'] = host
+        target['topic'] = '%s.%s' % (CONF.volume_topic, host)
 
         self.fake_args = None
         self.fake_kwargs = None
 
+        real_prepare = rpcapi.client.prepare
+
+        def _fake_prepare_method(*args, **kwds):
+            for kwd in kwds:
+                self.assertEqual(kwds[kwd], target[kwd])
+            return rpcapi.client
+
         def _fake_rpc_method(*args, **kwargs):
             self.fake_args = args
             self.fake_kwargs = kwargs
             if expected_retval:
                 return expected_retval
 
-        self.stubs.Set(rpc, rpc_method, _fake_rpc_method)
+        self.stubs.Set(rpcapi.client, "prepare", _fake_prepare_method)
+        self.stubs.Set(rpcapi.client, rpc_method, _fake_rpc_method)
 
         retval = getattr(rpcapi, method)(ctxt, **kwargs)
 
         self.assertEqual(retval, expected_retval)
-        expected_args = [ctxt, expected_topic, expected_msg]
+        expected_args = [ctxt, method]
+
         for arg, expected_arg in zip(self.fake_args, expected_args):
             self.assertEqual(arg, expected_arg)
 
+        for kwarg, value in self.fake_kwargs.items():
+            self.assertEqual(value, expected_msg[kwarg])
+
     def test_create_volume(self):
         self._test_volume_api('create_volume',
                               rpc_method='cast',
@@ -144,7 +167,9 @@ class VolumeRpcAPITestCase(test.TestCase):
     def test_delete_volume(self):
         self._test_volume_api('delete_volume',
                               rpc_method='cast',
-                              volume=self.fake_volume)
+                              volume=self.fake_volume,
+                              unmanage_only=False,
+                              version='1.15')
 
     def test_create_snapshot(self):
         self._test_volume_api('create_snapshot',
@@ -158,12 +183,25 @@ class VolumeRpcAPITestCase(test.TestCase):
                               snapshot=self.fake_snapshot,
                               host='fake_host')
 
-    def test_attach_volume(self):
+    def test_attach_volume_to_instance(self):
         self._test_volume_api('attach_volume',
                               rpc_method='call',
                               volume=self.fake_volume,
                               instance_uuid='fake_uuid',
-                              mountpoint='fake_mountpoint')
+                              host_name=None,
+                              mountpoint='fake_mountpoint',
+                              mode='ro',
+                              version='1.11')
+
+    def test_attach_volume_to_host(self):
+        self._test_volume_api('attach_volume',
+                              rpc_method='call',
+                              volume=self.fake_volume,
+                              instance_uuid=None,
+                              host_name='fake_host',
+                              mountpoint='fake_mountpoint',
+                              mode='rw',
+                              version='1.11')
 
     def test_detach_volume(self):
         self._test_volume_api('detach_volume',
@@ -191,3 +229,64 @@ class VolumeRpcAPITestCase(test.TestCase):
                               volume=self.fake_volume,
                               connector='fake_connector',
                               force=False)
+
+    def test_accept_transfer(self):
+        self._test_volume_api('accept_transfer',
+                              rpc_method='cast',
+                              volume=self.fake_volume,
+                              new_user='e5565fd0-06c8-11e3-'
+                                       '8ffd-0800200c9b77',
+                              new_project='e4465fd0-06c8-11e3'
+                                          '-8ffd-0800200c9a66',
+                              version='1.9')
+
+    def test_extend_volume(self):
+        self._test_volume_api('extend_volume',
+                              rpc_method='cast',
+                              volume=self.fake_volume,
+                              new_size=1,
+                              reservations=self.fake_reservations,
+                              version='1.14')
+
+    def test_migrate_volume(self):
+        class FakeHost(object):
+            def __init__(self):
+                self.host = 'host'
+                self.capabilities = {}
+        dest_host = FakeHost()
+        self._test_volume_api('migrate_volume',
+                              rpc_method='cast',
+                              volume=self.fake_volume,
+                              dest_host=dest_host,
+                              force_host_copy=True,
+                              version='1.8')
+
+    def test_migrate_volume_completion(self):
+        self._test_volume_api('migrate_volume_completion',
+                              rpc_method='call',
+                              volume=self.fake_volume,
+                              new_volume=self.fake_volume,
+                              error=False,
+                              version='1.10')
+
+    def test_retype(self):
+        class FakeHost(object):
+            def __init__(self):
+                self.host = 'host'
+                self.capabilities = {}
+        dest_host = FakeHost()
+        self._test_volume_api('retype',
+                              rpc_method='cast',
+                              volume=self.fake_volume,
+                              new_type_id='fake',
+                              dest_host=dest_host,
+                              migration_policy='never',
+                              reservations=None,
+                              version='1.12')
+
+    def test_manage_existing(self):
+        self._test_volume_api('manage_existing',
+                              rpc_method='cast',
+                              volume=self.fake_volume,
+                              ref={'lv_name': 'foo'},
+                              version='1.15')
