@@ -17,10 +17,11 @@
 # collisions with use of 'from cinder.transfer import <foo>' elsewhere.
 
 
-from oslo_config import cfg
-from oslo_utils import importutils
+from oslo.config import cfg
+
+import cinder.openstack.common.importutils
 
 
 CONF = cfg.CONF
 
-API = importutils.import_class(CONF.transfer_api_class)
+API = cinder.openstack.common.importutils.import_class(CONF.transfer_api_class)
