@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -20,14 +18,10 @@ Drivers for volumes.
 
 """
 
-import os
 import time
 
 from oslo.config import cfg
 
-from cinder.brick.initiator import connector as initiator
-from cinder.brick.iscsi import iscsi
-from cinder.brick.iser import iser
 from cinder import exception
 from cinder.image import image_utils
 from cinder.openstack.common import excutils
@@ -35,6 +29,7 @@ from cinder.openstack.common import fileutils
 from cinder.openstack.common import log as logging
 from cinder.openstack.common import processutils
 from cinder import utils
+from cinder.volume import iscsi
 from cinder.volume import rpcapi as volume_rpcapi
 from cinder.volume import utils as volume_utils
 
@@ -64,25 +59,6 @@ volume_opts = [
                default=3,
                help='The maximum number of times to rescan targets'
                     ' to find volume'),
-    cfg.IntOpt('num_iser_scan_tries',
-               default=3,
-               help='The maximum number of times to rescan iSER target'
-                    'to find volume'),
-    cfg.IntOpt('iser_num_targets',
-               default=100,
-               help='The maximum number of iser target ids per host'),
-    cfg.StrOpt('iser_target_prefix',
-               default='iqn.2010-10.org.iser.openstack:',
-               help='prefix for iser volumes'),
-    cfg.StrOpt('iser_ip_address',
-               default='$my_ip',
-               help='The IP address that the iSER daemon is listening on'),
-    cfg.IntOpt('iser_port',
-               default=3260,
-               help='The port that the iSER daemon is listening on'),
-    cfg.StrOpt('iser_helper',
-               default='tgtadm',
-               help='iser target user-land tool to use'),
     cfg.StrOpt('volume_backend_name',
                default=None,
                help='The backend name for a given driver implementation'),
@@ -97,6 +73,11 @@ volume_opts = [
     cfg.IntOpt('volume_clear_size',
                default=0,
                help='Size in MiB to wipe at start of old volumes. 0 => all'),
+    cfg.StrOpt('volume_clear_ionice',
+               default=None,
+               help='The flag to pass to ionice to alter the i/o priority '
+                    'of the process used to zero a volume after deletion, '
+                    'for example "-c3" for idle only priority.'),
     cfg.StrOpt('iscsi_helper',
                default='tgtadm',
                help='iscsi target user-land tool to use'),
@@ -117,11 +98,40 @@ volume_opts = [
                help=('Sets the behavior of the iSCSI target '
                      'to either perform blockio or fileio '
                      'optionally, auto can be set and Cinder '
-                     'will autodetect type of backing device'))]
+                     'will autodetect type of backing device')),
+    cfg.StrOpt('volume_dd_blocksize',
+               default='1M',
+               help='The default block size used when copying/clearing '
+                    'volumes'),
+]
+
+# for backward compatibility
+iser_opts = [
+    cfg.IntOpt('num_iser_scan_tries',
+               default=3,
+               help='The maximum number of times to rescan iSER target'
+                    'to find volume'),
+    cfg.IntOpt('iser_num_targets',
+               default=100,
+               help='The maximum number of iser target ids per host'),
+    cfg.StrOpt('iser_target_prefix',
+               default='iqn.2010-10.org.iser.openstack:',
+               help='prefix for iser volumes'),
+    cfg.StrOpt('iser_ip_address',
+               default='$my_ip',
+               help='The IP address that the iSER daemon is listening on'),
+    cfg.IntOpt('iser_port',
+               default=3260,
+               help='The port that the iSER daemon is listening on'),
+    cfg.StrOpt('iser_helper',
+               default='tgtadm',
+               help='iser target user-land tool to use'),
+]
 
 
 CONF = cfg.CONF
 CONF.register_opts(volume_opts)
+CONF.register_opts(iser_opts)
 
 
 class VolumeDriver(object):
@@ -132,13 +142,14 @@ class VolumeDriver(object):
     def __init__(self, execute=utils.execute, *args, **kwargs):
         # NOTE(vish): db is set by Manager
         self.db = kwargs.get('db')
+        self.host = kwargs.get('host')
         self.configuration = kwargs.get('configuration', None)
         if self.configuration:
             self.configuration.append_config_values(volume_opts)
         self.set_execute(execute)
         self._stats = {}
 
-        # set True by manager after succesful check_for_setup
+        # set True by manager after successful check_for_setup
         self._initialized = False
 
     def set_execute(self, execute):
@@ -255,23 +266,13 @@ class VolumeDriver(object):
         return None
 
     def do_setup(self, context):
-        """Any initialization the volume driver does while starting"""
+        """Any initialization the volume driver does while starting."""
         pass
 
     def validate_connector(self, connector):
-        """Fail if connector doesn't contain all the data needed by driver"""
+        """Fail if connector doesn't contain all the data needed by driver."""
         pass
 
-    def _copy_volume_data_cleanup(self, context, volume, properties,
-                                  attach_info, remote, force=False):
-        self._detach_volume(attach_info)
-        if remote:
-            rpcapi = volume_rpcapi.VolumeAPI()
-            rpcapi.terminate_connection(context, volume, properties,
-                                        force=force)
-        else:
-            self.terminate_connection(volume, properties, force=False)
-
     def copy_volume_data(self, context, src_vol, dest_vol, remote=None):
         """Copy data from src_vol to dest_vol."""
         LOG.debug(_('copy_data_between_volumes %(src)s -> %(dest)s.')
@@ -305,15 +306,16 @@ class VolumeDriver(object):
                 LOG.error(msg % {'vol': src_vol['id']})
                 self.db.volume_update(context, src_vol['id'],
                                       {'status': src_orig_status})
-                self._copy_volume_data_cleanup(context, dest_vol, properties,
-                                               dest_attach_info, dest_remote,
-                                               force=True)
+                self._detach_volume(context, dest_attach_info, dest_vol,
+                                    properties, force=True, remote=dest_remote)
 
         try:
             size_in_mb = int(src_vol['size']) * 1024    # vol size is in GB
-            volume_utils.copy_volume(src_attach_info['device']['path'],
-                                     dest_attach_info['device']['path'],
-                                     size_in_mb)
+            volume_utils.copy_volume(
+                src_attach_info['device']['path'],
+                dest_attach_info['device']['path'],
+                size_in_mb,
+                self.configuration.volume_dd_blocksize)
             copy_error = False
         except Exception:
             with excutils.save_and_reraise_exception():
@@ -321,12 +323,12 @@ class VolumeDriver(object):
                 LOG.error(msg % {'src': src_vol['id'], 'dest': dest_vol['id']})
                 copy_error = True
         finally:
-            self._copy_volume_data_cleanup(context, dest_vol, properties,
-                                           dest_attach_info, dest_remote,
-                                           force=copy_error)
-            self._copy_volume_data_cleanup(context, src_vol, properties,
-                                           src_attach_info, src_remote,
-                                           force=copy_error)
+            self._detach_volume(context, dest_attach_info, dest_vol,
+                                properties, force=copy_error,
+                                remote=dest_remote)
+            self._detach_volume(context, src_attach_info, src_vol,
+                                properties, force=copy_error,
+                                remote=src_remote)
 
     def copy_image_to_volume(self, context, volume, image_service, image_id):
         """Fetch the image from image_service and write it to the volume."""
@@ -340,10 +342,10 @@ class VolumeDriver(object):
                                      image_service,
                                      image_id,
                                      attach_info['device']['path'],
+                                     self.configuration.volume_dd_blocksize,
                                      size=volume['size'])
         finally:
-            self._detach_volume(attach_info)
-            self.terminate_connection(volume, properties)
+            self._detach_volume(context, attach_info, volume, properties)
 
     def copy_volume_to_image(self, context, volume, image_service, image_meta):
         """Copy the volume to the specified image."""
@@ -358,16 +360,50 @@ class VolumeDriver(object):
                                       image_meta,
                                       attach_info['device']['path'])
         finally:
-            self._detach_volume(attach_info)
-            self.terminate_connection(volume, properties)
+            self._detach_volume(context, attach_info, volume, properties)
 
     def _attach_volume(self, context, volume, properties, remote=False):
         """Attach the volume."""
         if remote:
+            # Call remote manager's initialize_connection which includes
+            # driver's create_export and initialize_connection
             rpcapi = volume_rpcapi.VolumeAPI()
             conn = rpcapi.initialize_connection(context, volume, properties)
         else:
-            conn = self.initialize_connection(volume, properties)
+            # Call local driver's create_export and initialize_connection.
+            # NOTE(avishay) This is copied from the manager's code - need to
+            # clean this up in the future.
+            model_update = None
+            try:
+                LOG.debug(_("Volume %s: creating export"), volume['id'])
+                model_update = self.create_export(context, volume)
+                if model_update:
+                    volume = self.db.volume_update(context, volume['id'],
+                                                   model_update)
+            except exception.CinderException as ex:
+                if model_update:
+                    LOG.exception(_("Failed updating model of volume "
+                                    "%(volume_id)s with driver provided model "
+                                    "%(model)s") %
+                                  {'volume_id': volume['id'],
+                                   'model': model_update})
+                    raise exception.ExportFailure(reason=ex)
+
+            try:
+                conn = self.initialize_connection(volume, properties)
+            except Exception as err:
+                try:
+                    err_msg = (_('Unable to fetch connection information from '
+                                 'backend: %(err)s') % {'err': err})
+                    LOG.error(err_msg)
+                    LOG.debug("Cleaning up failed connect initialization.")
+                    self.remove_export(context, volume)
+                except Exception as ex:
+                    ex_msg = (_('Error encountered during cleanup '
+                                'of a failed attach: %(ex)s') % {'ex': ex})
+                    LOG.error(err_msg)
+                    raise exception.VolumeBackendAPIException(data=ex_msg)
+                raise exception.VolumeBackendAPIException(data=err_msg)
 
         # Use Brick's code to do attach/detach
         use_multipath = self.configuration.use_multipath_for_image_xfer
@@ -390,14 +426,43 @@ class VolumeDriver(object):
                                                       {'path': host_device}))
         return {'conn': conn, 'device': device, 'connector': connector}
 
-    def _detach_volume(self, attach_info):
+    def _detach_volume(self, context, attach_info, volume, properties,
+                       force=False, remote=False):
         """Disconnect the volume from the host."""
         # Use Brick's code to do attach/detach
         connector = attach_info['connector']
         connector.disconnect_volume(attach_info['conn']['data'],
                                     attach_info['device'])
 
-    def clone_image(self, volume, image_location, image_id):
+        if remote:
+            # Call remote manager's terminate_connection which includes
+            # driver's terminate_connection and remove export
+            rpcapi = volume_rpcapi.VolumeAPI()
+            rpcapi.terminate_connection(context, volume, properties,
+                                        force=force)
+        else:
+            # Call local driver's terminate_connection and remove export.
+            # NOTE(avishay) This is copied from the manager's code - need to
+            # clean this up in the future.
+            try:
+                self.terminate_connection(volume, properties, force=force)
+            except Exception as err:
+                err_msg = (_('Unable to terminate volume connection: %(err)s')
+                           % {'err': err})
+                LOG.error(err_msg)
+                raise exception.VolumeBackendAPIException(data=err_msg)
+
+            try:
+                LOG.debug(_("volume %s: removing export"), volume['id'])
+                self.remove_export(context, volume)
+            except Exception as ex:
+                LOG.exception(_("Error detaching volume %(volume)s, "
+                                "due to remove export failure."),
+                              {"volume": volume['id']})
+                raise exception.RemoveExportException(volume=volume['id'],
+                                                      reason=ex)
+
+    def clone_image(self, volume, image_location, image_id, image_meta):
         """Create a volume efficiently from an existing image.
 
         image_location is a string whose format depends on the
@@ -408,6 +473,11 @@ class VolumeDriver(object):
         It can be used by the driver to introspect internal
         stores or registry to do an efficient image clone.
 
+        image_meta is a dictionary that includes 'disk_format' (e.g.
+        raw, qcow2) and other image attributes that allow drivers to
+        decide whether they can clone the image without first requiring
+        conversion.
+
         Returns a dict of volume properties eg. provider_location,
         boolean indicating whether cloning occurred
         """
@@ -430,8 +500,7 @@ class VolumeDriver(object):
                     backup_service.backup(backup, volume_file)
 
         finally:
-            self._detach_volume(attach_info)
-            self.terminate_connection(volume, properties)
+            self._detach_volume(context, attach_info, volume, properties)
 
     def restore_backup(self, context, backup, volume, backup_service):
         """Restore an existing backup to a new or existing volume."""
@@ -450,8 +519,7 @@ class VolumeDriver(object):
                     backup_service.restore(backup, volume['id'], volume_file)
 
         finally:
-            self._detach_volume(attach_info)
-            self.terminate_connection(volume, properties)
+            self._detach_volume(context, attach_info, volume, properties)
 
     def clear_download(self, context, volume):
         """Clean up after an interrupted image copy."""
@@ -466,9 +534,85 @@ class VolumeDriver(object):
 
         Returns a boolean indicating whether the migration occurred, as well as
         model_update.
+
+        :param ctxt: Context
+        :param volume: A dictionary describing the volume to migrate
+        :param host: A dictionary describing the host to migrate to, where
+                     host['host'] is its name, and host['capabilities'] is a
+                     dictionary of its reported capabilities.
         """
         return (False, None)
 
+    def retype(self, context, volume, new_type, diff, host):
+        """Convert the volume to be of the new type.
+
+        Returns a boolean indicating whether the retype occurred.
+
+        :param ctxt: Context
+        :param volume: A dictionary describing the volume to migrate
+        :param new_type: A dictionary describing the volume type to convert to
+        :param diff: A dictionary with the difference between the two types
+        :param host: A dictionary describing the host to migrate to, where
+                     host['host'] is its name, and host['capabilities'] is a
+                     dictionary of its reported capabilities.
+        """
+        return False
+
+    def accept_transfer(self, context, volume, new_user, new_project):
+        """Accept the transfer of a volume for a new user/project."""
+        pass
+
+    def manage_existing(self, volume, existing_ref):
+        """Brings an existing backend storage object under Cinder management.
+
+        existing_ref is passed straight through from the API request's
+        manage_existing_ref value, and it is up to the driver how this should
+        be interpreted.  It should be sufficient to identify a storage object
+        that the driver should somehow associate with the newly-created cinder
+        volume structure.
+
+        There are two ways to do this:
+
+        1. Rename the backend storage object so that it matches the,
+           volume['name'] which is how drivers traditionally map between a
+           cinder volume and the associated backend storage object.
+
+        2. Place some metadata on the volume, or somewhere in the backend, that
+           allows other driver requests (e.g. delete, clone, attach, detach...)
+           to locate the backend storage object when required.
+
+        If the existing_ref doesn't make sense, or doesn't refer to an existing
+        backend storage object, raise a ManageExistingInvalidReference
+        exception.
+
+        The volume may have a volume_type, and the driver can inspect that and
+        compare against the properties of the referenced backend storage
+        object.  If they are incompatible, raise a
+        ManageExistingVolumeTypeMismatch, specifying a reason for the failure.
+        """
+        msg = _("Manage existing volume not implemented.")
+        raise NotImplementedError(msg)
+
+    def manage_existing_get_size(self, volume, existing_ref):
+        """Return size of volume to be managed by manage_existing.
+
+        When calculating the size, round up to the next GB.
+        """
+        msg = _("Manage existing volume not implemented.")
+        raise NotImplementedError(msg)
+
+    def unmanage(self, volume):
+        """Removes the specified volume from Cinder management.
+
+        Does not delete the underlying backend storage object.
+
+        For most drivers, this will not need to do anything.  However, some
+        drivers might use this call as an opportunity to clean up any
+        Cinder-specific configuration that they have associated with the
+        backend storage object.
+        """
+        pass
+
 
 class ISCSIDriver(VolumeDriver):
     """Executes commands relating to ISCSI volumes.
@@ -496,9 +640,20 @@ class ISCSIDriver(VolumeDriver):
 
         volume_name = volume['name']
 
-        (out, _err) = self._execute('iscsiadm', '-m', 'discovery',
-                                    '-t', 'sendtargets', '-p', volume['host'],
-                                    run_as_root=True)
+        try:
+            # NOTE(griff) We're doing the split straight away which should be
+            # safe since using '@' in hostname is considered invalid
+
+            (out, _err) = self._execute('iscsiadm', '-m', 'discovery',
+                                        '-t', 'sendtargets', '-p',
+                                        volume['host'].split('@')[0],
+                                        run_as_root=True)
+        except processutils.ProcessExecutionError as ex:
+            LOG.error(_("ISCSI discovery attempt failed for:%s") %
+                      volume['host'].split('@')[0])
+            LOG.debug(_("Error from iscsiadm -m discovery: %s") % ex.stderr)
+            return None
+
         for target in out.splitlines():
             if (self.configuration.iscsi_ip_address in target
                     and volume_name in target):
@@ -633,7 +788,7 @@ class ISCSIDriver(VolumeDriver):
         """
 
         if CONF.iscsi_helper == 'lioadm':
-            self.tgtadm.initialize_connection(volume, connector)
+            self.target_helper.initialize_connection(volume, connector)
 
         iscsi_properties = self._get_iscsi_properties(volume)
         return {
@@ -652,15 +807,6 @@ class ISCSIDriver(VolumeDriver):
     def terminate_connection(self, volume, connector, **kwargs):
         pass
 
-    def _get_iscsi_initiator(self):
-        """Get iscsi initiator name for this machine"""
-        # NOTE openiscsi stores initiator name in a file that
-        #      needs root permission to read.
-        contents = utils.read_file_as_root('/etc/iscsi/initiatorname.iscsi')
-        for l in contents.split('\n'):
-            if l.startswith('InitiatorName='):
-                return l[l.index('=') + 1:].strip()
-
     def get_volume_stats(self, refresh=False):
         """Get volume stats.
 
@@ -688,24 +834,25 @@ class ISCSIDriver(VolumeDriver):
         data['QoS_support'] = False
         self._stats = data
 
-    def accept_transfer(self, context, volume, new_user, new_project):
-        pass
-
-    def get_target_admin(self):
+    def get_target_helper(self, db):
         root_helper = utils.get_root_helper()
-
-        if CONF.iscsi_helper == 'tgtadm':
+        if CONF.iscsi_helper == 'iseradm':
+            return iscsi.ISERTgtAdm(root_helper, CONF.volumes_dir,
+                                    CONF.iscsi_target_prefix, db=db)
+        elif CONF.iscsi_helper == 'tgtadm':
             return iscsi.TgtAdm(root_helper,
                                 CONF.volumes_dir,
-                                CONF.iscsi_target_prefix)
+                                CONF.iscsi_target_prefix,
+                                db=db)
         elif CONF.iscsi_helper == 'fake':
             return iscsi.FakeIscsiHelper()
         elif CONF.iscsi_helper == 'lioadm':
             return iscsi.LioAdm(root_helper,
                                 CONF.lio_initiator_iqns,
-                                CONF.iscsi_target_prefix)
+                                CONF.iscsi_target_prefix, db=db)
         else:
-            return iscsi.IetAdm(root_helper, CONF.iet_conf, CONF.iscsi_iotype)
+            return iscsi.IetAdm(root_helper, CONF.iet_conf, CONF.iscsi_iotype,
+                                db=db)
 
 
 class FakeISCSIDriver(ISCSIDriver):
@@ -752,91 +899,18 @@ class ISERDriver(ISCSIDriver):
       '<auth method> <auth username> <auth password>'.
       `CHAP` is the only auth_method in use at the moment.
     """
-
     def __init__(self, *args, **kwargs):
         super(ISERDriver, self).__init__(*args, **kwargs)
-
-    def _do_iser_discovery(self, volume):
-        LOG.warn(_("ISER provider_location not stored, using discovery"))
-
-        volume_name = volume['name']
-
-        (out, _err) = self._execute('iscsiadm', '-m', 'discovery',
-                                    '-t', 'sendtargets', '-p', volume['host'],
-                                    run_as_root=True)
-        for target in out.splitlines():
-            if (self.configuration.iser_ip_address in target
-                    and volume_name in target):
-                return target
-        return None
-
-    def _get_iser_properties(self, volume):
-        """Gets iser configuration
-
-        We ideally get saved information in the volume entity, but fall back
-        to discovery if need be. Discovery may be completely removed in future
-        The properties are:
-
-        :target_discovered:    boolean indicating whether discovery was used
-
-        :target_iqn:    the IQN of the iSER target
-
-        :target_portal:    the portal of the iSER target
-
-        :target_lun:    the lun of the iSER target
-
-        :volume_id:    the id of the volume (currently used by xen)
-
-        :auth_method:, :auth_username:, :auth_password:
-
-            the authentication details. Right now, either auth_method is not
-            present meaning no authentication, or auth_method == `CHAP`
-            meaning use CHAP with the specified credentials.
-        """
-
-        properties = {}
-
-        location = volume['provider_location']
-
-        if location:
-            # provider_location is the same format as iSER discovery output
-            properties['target_discovered'] = False
-        else:
-            location = self._do_iser_discovery(volume)
-
-            if not location:
-                msg = (_("Could not find iSER export for volume %s") %
-                        (volume['name']))
-                raise exception.InvalidVolume(reason=msg)
-
-            LOG.debug(_("ISER Discovery: Found %s") % (location))
-            properties['target_discovered'] = True
-
-        results = location.split(" ")
-        properties['target_portal'] = results[0].split(",")[0]
-        properties['target_iqn'] = results[1]
-        try:
-            properties['target_lun'] = int(results[2])
-        except (IndexError, ValueError):
-            if (self.configuration.volume_driver in
-                    ['cinder.volume.drivers.lvm.LVMISERDriver',
-                     'cinder.volume.drivers.lvm.ThinLVMVolumeDriver'] and
-                    self.configuration.iser_helper == 'tgtadm'):
-                properties['target_lun'] = 1
-            else:
-                properties['target_lun'] = 0
-
-        properties['volume_id'] = volume['id']
-
-        auth = volume['provider_auth']
-        if auth:
-            (auth_method, auth_username, auth_secret) = auth.split()
-
-            properties['auth_method'] = auth_method
-            properties['auth_username'] = auth_username
-            properties['auth_password'] = auth_secret
-
-        return properties
+        # for backward compatibility
+        self.configuration.num_iscsi_scan_tries = \
+            self.configuration.num_iser_scan_tries
+        self.configuration.iscsi_num_targets = \
+            self.configuration.iser_num_targets
+        self.configuration.iscsi_target_prefix = \
+            self.configuration.iser_target_prefix
+        self.configuration.iscsi_ip_address = \
+            self.configuration.iser_ip_address
+        self.configuration.iser_port = self.configuration.iser_port
 
     def initialize_connection(self, volume, connector):
         """Initializes the connection and returns connection info.
@@ -858,127 +932,16 @@ class ISERDriver(ISCSIDriver):
 
         """
 
-        iser_properties = self._get_iser_properties(volume)
+        iser_properties = self._get_iscsi_properties(volume)
         return {
             'driver_volume_type': 'iser',
             'data': iser_properties
         }
 
-    def _check_valid_device(self, path):
-        cmd = ('dd', 'if=%(path)s' % {"path": path},
-               'of=/dev/null', 'count=1')
-        out, info = None, None
-        try:
-            out, info = self._execute(*cmd, run_as_root=True)
-        except processutils.ProcessExecutionError as e:
-            LOG.error(_("Failed to access the device on the path "
-                        "%(path)s: %(error)s.") %
-                      {"path": path, "error": e.stderr})
-            return False
-        # If the info is none, the path does not exist.
-        if info is None:
-            return False
-        return True
+    def _update_volume_stats(self):
+        """Retrieve stats info from volume group."""
 
-    def _attach_volume(self, context, volume, connector):
-        """Attach the volume."""
-        iser_properties = None
-        host_device = None
-        init_conn = self.initialize_connection(volume, connector)
-        iser_properties = init_conn['data']
-
-        # code "inspired by" nova/virt/libvirt/volume.py
-        try:
-            self._run_iscsiadm(iser_properties, ())
-        except processutils.ProcessExecutionError as exc:
-            # iscsiadm returns 21 for "No records found" after version 2.0-871
-            if exc.exit_code in [21, 255]:
-                self._run_iscsiadm(iser_properties, ('--op', 'new'))
-            else:
-                raise
-
-        if iser_properties.get('auth_method'):
-            self._iscsiadm_update(iser_properties,
-                                  "node.session.auth.authmethod",
-                                  iser_properties['auth_method'])
-            self._iscsiadm_update(iser_properties,
-                                  "node.session.auth.username",
-                                  iser_properties['auth_username'])
-            self._iscsiadm_update(iser_properties,
-                                  "node.session.auth.password",
-                                  iser_properties['auth_password'])
-
-        host_device = ("/dev/disk/by-path/ip-%s-iser-%s-lun-%s" %
-                       (iser_properties['target_portal'],
-                        iser_properties['target_iqn'],
-                        iser_properties.get('target_lun', 0)))
-
-        out = self._run_iscsiadm_bare(["-m", "session"],
-                                      run_as_root=True,
-                                      check_exit_code=[0, 1, 21])[0] or ""
-
-        portals = [{'portal': p.split(" ")[2], 'iqn': p.split(" ")[3]}
-                   for p in out.splitlines() if p.startswith("iser:")]
-
-        stripped_portal = iser_properties['target_portal'].split(",")[0]
-        length_iqn = [s for s in portals
-                      if stripped_portal ==
-                      s['portal'].split(",")[0] and
-                      s['iqn'] == iser_properties['target_iqn']]
-        if len(portals) == 0 or len(length_iqn) == 0:
-            try:
-                self._run_iscsiadm(iser_properties, ("--login",),
-                                   check_exit_code=[0, 255])
-            except processutils.ProcessExecutionError as err:
-                if err.exit_code in [15]:
-                    self._iscsiadm_update(iser_properties,
-                                          "node.startup",
-                                          "automatic")
-                    return iser_properties, host_device
-                else:
-                    raise
-
-            self._iscsiadm_update(iser_properties,
-                                  "node.startup", "automatic")
-
-            tries = 0
-            while not os.path.exists(host_device):
-                if tries >= self.configuration.num_iser_scan_tries:
-                    raise exception.CinderException(_("iSER device "
-                                                      "not found "
-                                                      "at %s") % (host_device))
-
-                LOG.warn(_("ISER volume not yet found at: %(host_device)s. "
-                           "Will rescan & retry.  Try number: %(tries)s.") %
-                         {'host_device': host_device, 'tries': tries})
-
-                # The rescan isn't documented as being necessary(?),
-                # but it helps
-                self._run_iscsiadm(iser_properties, ("--rescan",))
-
-                tries = tries + 1
-                if not os.path.exists(host_device):
-                    time.sleep(tries ** 2)
-
-            if tries != 0:
-                LOG.debug(_("Found iSER node %(host_device)s "
-                            "(after %(tries)s rescans).") %
-                          {'host_device': host_device,
-                           'tries': tries})
-
-        if not self._check_valid_device(host_device):
-            raise exception.DeviceUnavailable(path=host_device,
-                                              reason=(_("Unable to access "
-                                                        "the backend storage "
-                                                        "via the path "
-                                                        "%(path)s.") %
-                                                      {'path': host_device}))
-        return iser_properties, host_device
-
-    def _update_volume_status(self):
-        """Retrieve status info from volume group."""
-
-        LOG.debug(_("Updating volume status"))
+        LOG.debug(_("Updating volume stats"))
         data = {}
         backend_name = self.configuration.safe_get('volume_backend_name')
         data["volume_backend_name"] = backend_name or 'Generic_iSER'
@@ -992,14 +955,14 @@ class ISERDriver(ISCSIDriver):
         data['QoS_support'] = False
         self._stats = data
 
-    def get_target_admin(self):
+    def get_target_helper(self, db):
         root_helper = utils.get_root_helper()
 
         if CONF.iser_helper == 'fake':
-            return iser.FakeIserHelper()
+            return iscsi.FakeIscsiHelper()
         else:
-            return iser.TgtAdm(root_helper,
-                               CONF.volumes_dir)
+            return iscsi.ISERTgtAdm(root_helper,
+                                    CONF.volumes_dir, db=db)
 
 
 class FakeISERDriver(FakeISCSIDriver):
