@@ -1,7 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright (c) 2012 EMC Corporation.
-# Copyright (c) 2012 OpenStack Foundation
+# Copyright (c) 2012 - 2014 EMC Corporation.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -21,6 +18,7 @@ ISCSI Drivers for EMC VNX and VMAX arrays based on SMI-S.
 """
 
 
+from cinder import context
 from cinder import exception
 from cinder.openstack.common import log as logging
 from cinder.volume import driver
@@ -30,9 +28,15 @@ LOG = logging.getLogger(__name__)
 
 
 class EMCSMISISCSIDriver(driver.ISCSIDriver):
-    """EMC ISCSI Drivers for VMAX and VNX using SMI-S."""
+    """EMC ISCSI Drivers for VMAX and VNX using SMI-S.
 
-    VERSION = "1.0.0"
+    Version history:
+        1.0.0 - Initial driver
+        1.1.0 - Multiple pools and thick/thin provisioning,
+                performance enhancement.
+    """
+
+    VERSION = "1.1.0"
 
     def __init__(self, *args, **kwargs):
 
@@ -46,15 +50,33 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
 
     def create_volume(self, volume):
         """Creates a EMC(VMAX/VNX) volume."""
-        self.common.create_volume(volume)
+        volpath = self.common.create_volume(volume)
+
+        ctxt = context.get_admin_context()
+        model_update = {}
+        volume['provider_location'] = str(volpath)
+        model_update['provider_location'] = volume['provider_location']
+        return model_update
 
     def create_volume_from_snapshot(self, volume, snapshot):
         """Creates a volume from a snapshot."""
-        self.common.create_volume_from_snapshot(volume, snapshot)
+        volpath = self.common.create_volume_from_snapshot(volume, snapshot)
+
+        ctxt = context.get_admin_context()
+        model_update = {}
+        volume['provider_location'] = str(volpath)
+        model_update['provider_location'] = volume['provider_location']
+        return model_update
 
     def create_cloned_volume(self, volume, src_vref):
         """Creates a cloned volume."""
-        self.common.create_cloned_volume(volume, src_vref)
+        volpath = self.common.create_cloned_volume(volume, src_vref)
+
+        ctxt = context.get_admin_context()
+        model_update = {}
+        volume['provider_location'] = str(volpath)
+        model_update['provider_location'] = volume['provider_location']
+        return model_update
 
     def delete_volume(self, volume):
         """Deletes an EMC volume."""
@@ -62,11 +84,28 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
 
     def create_snapshot(self, snapshot):
         """Creates a snapshot."""
-        self.common.create_snapshot(snapshot)
+        ctxt = context.get_admin_context()
+        volumename = snapshot['volume_name']
+        index = volumename.index('-')
+        volumeid = volumename[index + 1:]
+        volume = self.db.volume_get(ctxt, volumeid)
+
+        volpath = self.common.create_snapshot(snapshot, volume)
+
+        model_update = {}
+        snapshot['provider_location'] = str(volpath)
+        model_update['provider_location'] = snapshot['provider_location']
+        return model_update
 
     def delete_snapshot(self, snapshot):
         """Deletes a snapshot."""
-        self.common.delete_snapshot(snapshot)
+        ctxt = context.get_admin_context()
+        volumename = snapshot['volume_name']
+        index = volumename.index('-')
+        volumeid = volumename[index + 1:]
+        volume = self.db.volume_get(ctxt, volumeid)
+
+        self.common.delete_snapshot(snapshot, volume)
 
     def ensure_export(self, context, volume):
         """Driver entry point to get the export info for an existing volume."""
@@ -74,7 +113,7 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
 
     def create_export(self, context, volume):
         """Driver entry point to get the export info for a new volume."""
-        return self.common.create_export(context, volume)
+        pass
 
     def remove_export(self, context, volume):
         """Driver entry point to remove an export for a volume."""
@@ -88,7 +127,7 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
         """Initializes the connection and returns connection info.
 
         The iscsi driver returns a driver_volume_type of 'iscsi'.
-        the format of the driver data is defined in _get_iscsi_properties.
+        the format of the driver data is defined in smis_get_iscsi_properties.
         Example return value::
 
             {
@@ -97,14 +136,14 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
                     'target_discovered': True,
                     'target_iqn': 'iqn.2010-10.org.openstack:volume-00000001',
                     'target_portal': '127.0.0.0.1:3260',
-                    'volume_id': 1,
+                    'volume_id': '12345678-1234-4321-1234-123456789012',
                 }
             }
 
         """
         self.common.initialize_connection(volume, connector)
 
-        iscsi_properties = self._get_iscsi_properties(volume)
+        iscsi_properties = self.smis_get_iscsi_properties(volume, connector)
         return {
             'driver_volume_type': 'iscsi',
             'data': iscsi_properties
@@ -124,7 +163,7 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
 
         return targets
 
-    def _get_iscsi_properties(self, volume):
+    def smis_get_iscsi_properties(self, volume, connector):
         """Gets iscsi configuration.
 
         We ideally get saved information in the volume entity, but fall back
@@ -139,7 +178,7 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
 
         :target_lun:    the lun of the iSCSI target
 
-        :volume_id:    the id of the volume (currently used by xen)
+        :volume_id:    the UUID of the volume
 
         :auth_method:, :auth_username:, :auth_password:
 
@@ -158,7 +197,7 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
         LOG.debug(_("ISCSI Discovery: Found %s") % (location))
         properties['target_discovered'] = True
 
-        device_info = self.common.find_device_number(volume)
+        device_info = self.common.find_device_number(volume, connector)
         if device_info is None or device_info['hostlunid'] is None:
             exception_message = (_("Cannot find device number for volume %s")
                                  % volume['name'])
@@ -171,7 +210,7 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
         sp = device_info['owningsp']
         endpoints = []
         if sp:
-            # endpointss example:
+            # endpoints example:
             # [iqn.1992-04.com.emc:cx.apm00123907237.a8,
             # iqn.1992-04.com.emc:cx.apm00123907237.a9]
             endpoints = self.common._find_iscsi_protocol_endpoints(
@@ -206,6 +245,8 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
 
         properties['volume_id'] = volume['id']
 
+        LOG.debug(_("ISCSI properties: %s") % (properties))
+
         auth = volume['provider_auth']
         if auth:
             (auth_method, auth_username, auth_secret) = auth.split()
@@ -214,14 +255,16 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
             properties['auth_username'] = auth_username
             properties['auth_password'] = auth_secret
 
-        LOG.debug(_("ISCSI properties: %s") % (properties))
-
         return properties
 
     def terminate_connection(self, volume, connector, **kwargs):
         """Disallow connection from connector."""
         self.common.terminate_connection(volume, connector)
 
+    def extend_volume(self, volume, new_size):
+        """Extend an existing volume."""
+        self.common.extend_volume(volume, new_size)
+
     def get_volume_stats(self, refresh=False):
         """Get volume stats.
 
@@ -239,4 +282,5 @@ class EMCSMISISCSIDriver(driver.ISCSIDriver):
         backend_name = self.configuration.safe_get('volume_backend_name')
         data['volume_backend_name'] = backend_name or 'EMCSMISISCSIDriver'
         data['storage_protocol'] = 'iSCSI'
+        data['driver_version'] = self.VERSION
         self._stats = data
