@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2013 Huawei Technologies Co., Ltd.
 # Copyright (c) 2012 OpenStack Foundation
 # All Rights Reserved.
@@ -81,7 +79,7 @@ class HuaweiDoradoFCDriver(huawei_t.HuaweiTFCDriver):
 
         self.common._update_login_info()
         # First, add a host if it is not added before.
-        host_id = self.common.add_host(connector['host'])
+        host_id = self.common.add_host(connector['host'], connector['ip'])
         # Then, add free FC ports to the host.
         ini_wwns = connector['wwpns']
         free_wwns = self._get_connected_free_wwns()
