@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2012 NetApp, Inc.
 # Copyright (c) 2012 OpenStack Foundation
 # All Rights Reserved.
@@ -21,8 +19,6 @@ Unified driver for NetApp storage systems.
 Supports call to multiple storage systems of different families and protocols.
 """
 
-from oslo.config import cfg
-
 from cinder import exception
 from cinder.openstack.common import importutils
 from cinder.openstack.common import log as logging
@@ -33,10 +29,6 @@ from cinder.volume.drivers.netapp.options import netapp_proxy_opts
 LOG = logging.getLogger(__name__)
 
 
-CONF = cfg.CONF
-CONF.register_opts(netapp_proxy_opts)
-
-
 #NOTE(singn): Holds family:{protocol:driver} registration information.
 #Plug in new families and protocols to support new drivers.
 #No other code modification required.
@@ -52,6 +44,10 @@ netapp_unified_plugin_registry =\
             'cinder.volume.drivers.netapp.iscsi.NetAppDirect7modeISCSIDriver',
             'nfs':
             'cinder.volume.drivers.netapp.nfs.NetAppDirect7modeNfsDriver'
+        }, 'eseries':
+        {
+            'iscsi':
+            'cinder.volume.drivers.netapp.eseries.iscsi.Driver'
         },
      }
 
@@ -61,7 +57,8 @@ netapp_unified_plugin_registry =\
 netapp_family_default =\
     {
         'ontap_cluster': 'nfs',
-        'ontap_7mode': 'nfs'
+        'ontap_7mode': 'nfs',
+        'eseries': 'iscsi'
     }
 
 
