@@ -26,6 +26,7 @@ from cinder import exception
 from cinder.image import image_utils
 from cinder.openstack.common import fileutils
 from cinder.openstack.common import log as logging
+from cinder.openstack.common import strutils
 from cinder import units
 from cinder.volume import driver
 
@@ -339,8 +340,8 @@ class RBDDriver(driver.VolumeDriver):
         try:
             with RADOSClient(self) as client:
                 new_stats = client.cluster.get_cluster_stats()
-            stats['total_capacity_gb'] = new_stats['kb'] / 1024 ** 2
-            stats['free_capacity_gb'] = new_stats['kb_avail'] / 1024 ** 2
+            stats['total_capacity_gb'] = new_stats['kb'] / units.MiB
+            stats['free_capacity_gb'] = new_stats['kb_avail'] / units.MiB
         except self.rados.Error:
             # just log and return unknown capacities
             LOG.exception(_('error refreshing volume stats'))
@@ -371,7 +372,7 @@ class RBDDriver(driver.VolumeDriver):
         if not parent:
             return depth
 
-        # If clone depth was reached, flatten should have occured so if it has
+        # If clone depth was reached, flatten should have occurred so if it has
         # been exceeded then something has gone wrong.
         if depth > CONF.rbd_max_clone_depth:
             raise Exception(_("clone depth exceeds limit of %s") %
@@ -585,15 +586,15 @@ class RBDDriver(driver.VolumeDriver):
 
     def delete_volume(self, volume):
         """Deletes a logical volume."""
-        volume_name = str(volume['name'])
+        # NOTE(dosaboy): this was broken by commit cbe1d5f. Ensure names are
+        #                utf-8 otherwise librbd will barf.
+        volume_name = strutils.safe_encode(volume['name'])
         with RADOSClient(self) as client:
-            # If the volume has non-clone snapshots this delete is expected to
-            # raise VolumeIsBusy so do so straight away.
             try:
                 rbd_image = self.rbd.Image(client.ioctx, volume_name)
             except self.rbd.ImageNotFound:
-                LOG.debug(_("volume %s no longer exists in backend")
-                          % (volume_name))
+                LOG.info(_("volume %s no longer exists in backend")
+                         % (volume_name))
                 return
 
             clone_snap = None
@@ -602,13 +603,15 @@ class RBDDriver(driver.VolumeDriver):
             # Ensure any backup snapshots are deleted
             self._delete_backup_snaps(client, volume_name)
 
+            # If the volume has non-clone snapshots this delete is expected to
+            # raise VolumeIsBusy so do so straight away.
             try:
                 snaps = rbd_image.list_snaps()
                 for snap in snaps:
                     if snap['name'].endswith('.clone_snap'):
                         LOG.debug(_("volume has clone snapshot(s)"))
                         # We grab one of these and use it when fetching parent
-                        # info in case the this volume has been flattened.
+                        # info in case the volume has been flattened.
                         clone_snap = snap['name']
                         break
 
@@ -631,7 +634,7 @@ class RBDDriver(driver.VolumeDriver):
                              "connection from a client that has crashed and, "
                              "if so, may be resolved by retrying the delete "
                              "after 30 seconds has elapsed."))
-                    LOG.error(msg)
+                    LOG.warn(msg)
                     # Now raise this so that volume stays available so that we
                     # delete can be retried.
                     raise exception.VolumeIsBusy(msg, volume_name=volume_name)
@@ -658,14 +661,17 @@ class RBDDriver(driver.VolumeDriver):
 
     def delete_snapshot(self, snapshot):
         """Deletes an rbd snapshot."""
-        with RBDVolumeProxy(self, snapshot['volume_name']) as volume:
-            snap = str(snapshot['name'])
+        # NOTE(dosaboy): this was broken by commit cbe1d5f. Ensure names are
+        #                utf-8 otherwise librbd will barf.
+        volume_name = strutils.safe_encode(snapshot['volume_name'])
+        snap_name = strutils.safe_encode(snapshot['name'])
+        with RBDVolumeProxy(self, volume_name) as volume:
             if self._supports_layering():
                 try:
-                    volume.unprotect_snap(snap)
+                    volume.unprotect_snap(snap_name)
                 except self.rbd.ImageBusy:
-                    raise exception.SnapshotIsBusy(snapshot_name=snap)
-            volume.remove_snap(snap)
+                    raise exception.SnapshotIsBusy(snapshot_name=snap_name)
+            volume.remove_snap(snap_name)
 
     def ensure_export(self, context, volume):
         """Synchronously recreates an export for a logical volume."""
@@ -717,7 +723,7 @@ class RBDDriver(driver.VolumeDriver):
         with RADOSClient(self) as client:
             return client.cluster.get_fsid()
 
-    def _is_cloneable(self, image_location):
+    def _is_cloneable(self, image_location, image_meta):
         try:
             fsid, pool, image, snapshot = self._parse_location(image_location)
         except exception.ImageUnacceptable as e:
@@ -729,6 +735,13 @@ class RBDDriver(driver.VolumeDriver):
             LOG.debug(reason)
             return False
 
+        if image_meta['disk_format'] != 'raw':
+            reason = _("rbd image clone requires image format to be "
+                       "'raw' but image {0} is '{1}'").format(
+                           image_location, image_meta['disk_format'])
+            LOG.debug(reason)
+            return False
+
         # check that we can read the image
         try:
             with RBDVolumeProxy(self, image,
@@ -741,9 +754,10 @@ class RBDDriver(driver.VolumeDriver):
                       dict(loc=image_location, err=e))
             return False
 
-    def clone_image(self, volume, image_location, image_id):
+    def clone_image(self, volume, image_location, image_id, image_meta):
         image_location = image_location[0] if image_location else None
-        if image_location is None or not self._is_cloneable(image_location):
+        if image_location is None or not self._is_cloneable(
+                image_location, image_meta):
             return ({}, False)
         prefix, pool, image, snapshot = self._parse_location(image_location)
         self._clone(volume, pool, image, snapshot)
@@ -761,7 +775,9 @@ class RBDDriver(driver.VolumeDriver):
 
         with tempfile.NamedTemporaryFile(dir=tmp_dir) as tmp:
             image_utils.fetch_to_raw(context, image_service, image_id,
-                                     tmp.name, size=volume['size'])
+                                     tmp.name,
+                                     self.configuration.volume_dd_blocksize,
+                                     size=volume['size'])
 
             self.delete_volume(volume)
 
