@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -26,7 +24,7 @@ from cinder.volume.drivers.xenapi import tools
 
 class XenAPIException(Exception):
     def __init__(self, original_exception):
-        super(XenAPIException, self).__init__(str(original_exception))
+        super(XenAPIException, self).__init__(original_exception)
         self.original_exception = original_exception
 
 
