@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -19,7 +17,6 @@
 from oslo.config import cfg
 
 from cinder import exception
-from cinder import flags
 from cinder.image import glance
 from cinder.image import image_utils
 from cinder.openstack.common import log as logging
@@ -53,12 +50,15 @@ xenapi_nfs_opts = [
                help='Path of exported NFS, used by XenAPINFSDriver'),
 ]
 
-FLAGS = flags.FLAGS
-FLAGS.register_opts(xenapi_opts)
-FLAGS.register_opts(xenapi_nfs_opts)
+CONF = cfg.CONF
+CONF.register_opts(xenapi_opts)
+CONF.register_opts(xenapi_nfs_opts)
 
 
 class XenAPINFSDriver(driver.VolumeDriver):
+
+    VERSION = "1.0.0"
+
     def __init__(self, *args, **kwargs):
         super(XenAPINFSDriver, self).__init__(*args, **kwargs)
         self.configuration.append_config_values(xenapi_opts)
@@ -119,11 +119,11 @@ class XenAPINFSDriver(driver.VolumeDriver):
             )
         )
 
-    def terminate_connection(self, volume, connector, force=False, **kwargs):
+    def terminate_connection(self, volume, connector, **kwargs):
         pass
 
     def check_for_setup_error(self):
-        """To override superclass' method"""
+        """To override superclass' method."""
 
     def create_volume_from_snapshot(self, volume, snapshot):
         return self._copy_volume(
@@ -156,7 +156,7 @@ class XenAPINFSDriver(driver.VolumeDriver):
         pass
 
     def copy_image_to_volume(self, context, volume, image_service, image_id):
-        if is_xenserver_image(context, image_service, image_id):
+        if image_utils.is_xenserver_image(context, image_service, image_id):
             return self._use_glance_plugin_to_copy_image_to_volume(
                 context, volume, image_service, image_id)
 
@@ -166,14 +166,16 @@ class XenAPINFSDriver(driver.VolumeDriver):
     def _use_image_utils_to_pipe_bytes_to_volume(self, context, volume,
                                                  image_service, image_id):
         sr_uuid, vdi_uuid = volume['provider_location'].split('/')
-        with self.nfs_ops.volume_attached_here(FLAGS.xenapi_nfs_server,
-                                               FLAGS.xenapi_nfs_serverpath,
+        with self.nfs_ops.volume_attached_here(CONF.xenapi_nfs_server,
+                                               CONF.xenapi_nfs_serverpath,
                                                sr_uuid, vdi_uuid,
                                                False) as device:
             image_utils.fetch_to_raw(context,
                                      image_service,
                                      image_id,
-                                     device)
+                                     device,
+                                     self.configuration.volume_dd_blocksize,
+                                     size=volume['size'])
 
     def _use_glance_plugin_to_copy_image_to_volume(self, context, volume,
                                                    image_service, image_id):
@@ -184,28 +186,28 @@ class XenAPINFSDriver(driver.VolumeDriver):
         auth_token = context.auth_token
 
         overwrite_result = self.nfs_ops.use_glance_plugin_to_overwrite_volume(
-            FLAGS.xenapi_nfs_server,
-            FLAGS.xenapi_nfs_serverpath,
+            CONF.xenapi_nfs_server,
+            CONF.xenapi_nfs_serverpath,
             sr_uuid,
             vdi_uuid,
             glance_server,
             image_id,
             auth_token,
-            FLAGS.xenapi_sr_base_path)
+            CONF.xenapi_sr_base_path)
 
         if overwrite_result is False:
             raise exception.ImageCopyFailure(reason='Overwriting volume '
                                                     'failed.')
 
         self.nfs_ops.resize_volume(
-            FLAGS.xenapi_nfs_server,
-            FLAGS.xenapi_nfs_serverpath,
+            CONF.xenapi_nfs_server,
+            CONF.xenapi_nfs_serverpath,
             sr_uuid,
             vdi_uuid,
             volume['size'])
 
     def copy_volume_to_image(self, context, volume, image_service, image_meta):
-        if is_xenserver_format(image_meta):
+        if image_utils.is_xenserver_format(image_meta):
             return self._use_glance_plugin_to_upload_volume(
                 context, volume, image_service, image_meta)
 
@@ -215,8 +217,8 @@ class XenAPINFSDriver(driver.VolumeDriver):
     def _use_image_utils_to_upload_volume(self, context, volume, image_service,
                                           image_meta):
         sr_uuid, vdi_uuid = volume['provider_location'].split('/')
-        with self.nfs_ops.volume_attached_here(FLAGS.xenapi_nfs_server,
-                                               FLAGS.xenapi_nfs_serverpath,
+        with self.nfs_ops.volume_attached_here(CONF.xenapi_nfs_server,
+                                               CONF.xenapi_nfs_serverpath,
                                                sr_uuid, vdi_uuid,
                                                True) as device:
             image_utils.upload_volume(context,
@@ -235,14 +237,14 @@ class XenAPINFSDriver(driver.VolumeDriver):
         auth_token = context.auth_token
 
         self.nfs_ops.use_glance_plugin_to_upload_volume(
-            FLAGS.xenapi_nfs_server,
-            FLAGS.xenapi_nfs_serverpath,
+            CONF.xenapi_nfs_server,
+            CONF.xenapi_nfs_serverpath,
             sr_uuid,
             vdi_uuid,
             glance_server,
             image_id,
             auth_token,
-            FLAGS.xenapi_sr_base_path)
+            CONF.xenapi_sr_base_path)
 
     def get_volume_stats(self, refresh=False):
         if refresh or not self._stats:
@@ -251,7 +253,7 @@ class XenAPINFSDriver(driver.VolumeDriver):
             backend_name = self.configuration.safe_get('volume_backend_name')
             data["volume_backend_name"] = backend_name or 'XenAPINFS',
             data['vendor_name'] = 'Open Source',
-            data['driver_version'] = '1.0'
+            data['driver_version'] = self.VERSION
             data['storage_protocol'] = 'xensm'
             data['total_capacity_gb'] = 'unknown'
             data['free_capacity_gb'] = 'unknown'
@@ -260,14 +262,10 @@ class XenAPINFSDriver(driver.VolumeDriver):
 
         return self._stats
 
+    def backup_volume(self, context, backup, backup_service):
+        """Create a new backup from an existing volume."""
+        raise NotImplementedError()
 
-def is_xenserver_image(context, image_service, image_id):
-    image_meta = image_service.show(context, image_id)
-    return is_xenserver_format(image_meta)
-
-
-def is_xenserver_format(image_meta):
-    return (
-        image_meta['disk_format'] == 'vhd'
-        and image_meta['container_format'] == 'ovf'
-    )
+    def restore_backup(self, context, backup, volume, backup_service):
+        """Restore an existing backup to a new or existing volume."""
+        raise NotImplementedError()
