@@ -16,9 +16,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
+import six
 
 from cinder import exception
+from cinder.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
@@ -49,43 +50,44 @@ def restore_source_status(context, db, volume_spec):
     source_volid = volume_spec['source_volid']
     source_status = volume_spec['source_volstatus']
     try:
-        LOG.debug('Restoring source %(source_volid)s status to %(status)s',
+        LOG.debug(_('Restoring source %(source_volid)s status to %(status)s') %
                   {'status': source_status, 'source_volid': source_volid})
         db.volume_update(context, source_volid, {'status': source_status})
     except exception.CinderException:
         # NOTE(harlowja): Don't let this cause further exceptions since this is
         # a non-critical failure.
-        LOG.exception("Failed setting source "
-                      "volume %(source_volid)s back to"
-                      " its initial %(source_status)s status",
+        LOG.exception(_("Failed setting source volume %(source_volid)s back to"
+                        " its initial %(source_status)s status") %
                       {'source_status': source_status,
                        'source_volid': source_volid})
 
 
-def _clean_reason(reason):
-    if reason is None:
-        return 'Unknown reason'
-    reason = str(reason)
-    if len(reason) <= REASON_LENGTH:
-        return reason
-    else:
-        return reason[0:REASON_LENGTH] + '...'
+def error_out_volume(context, db, volume_id, reason=None):
 
+    def _clean_reason(reason):
+        if reason is None:
+            return '???'
+        reason = six.text_type(reason)
+        if len(reason) <= REASON_LENGTH:
+            return reason
+        else:
+            return reason[0:REASON_LENGTH] + '...'
 
-def error_out(resource, reason=None, status='error'):
-    """Sets status to error for any persistent OVO."""
+    update = {
+        'status': 'error',
+    }
     reason = _clean_reason(reason)
+    # TODO(harlowja): re-enable when we can support this in the database.
+    # if reason:
+    #     status['details'] = reason
     try:
-        LOG.debug('Setting %(object_type)s %(object_id)s to error due to: '
-                  '%(reason)s', {'object_type': resource.obj_name(),
-                                 'object_id': resource.id,
-                                 'reason': reason})
-        resource.status = status
-        resource.save()
-    except Exception:
+        LOG.debug(_('Updating volume: %(volume_id)s with %(update)s'
+                    ' due to: %(reason)s') % {'volume_id': volume_id,
+                                              'reason': reason,
+                                              'update': update})
+        db.volume_update(context, volume_id, update)
+    except exception.CinderException:
         # Don't let this cause further exceptions.
-        LOG.exception("Failed setting %(object_type)s %(object_id)s to "
-                      " %(status)s status.",
-                      {'object_type': resource.obj_name(),
-                       'object_id': resource.id,
-                       'status': status})
+        LOG.exception(_("Failed updating volume %(volume_id)s with"
+                        " %(update)s") % {'volume_id': volume_id,
+                                          'update': update})
