@@ -18,8 +18,8 @@ import re
 
 from oslo.config import cfg
 
-from cinder.brick import exception
 from cinder.brick.iscsi import iscsi
+from cinder import exception
 from cinder.openstack.common.gettextutils import _
 from cinder.openstack.common import log as logging
 from cinder.openstack.common import processutils as putils
