@@ -684,11 +684,18 @@ class VolumeManager(manager.SchedulerDependentManager):
         volume = self.db.volume_get(context, volume_id)
         try:
             utils.require_driver_initialized(self.driver)
+            LOG.debug(_("volume %s: removing export"), volume_id)
+            self.driver.remove_export(context.elevated(), volume)
         except exception.DriverNotInitialized as ex:
             with excutils.save_and_reraise_exception():
                 LOG.exception(_("Error detaching volume %(volume)s, "
                                 "due to uninitialized driver."),
                               {"volume": volume_id})
+        except Exception as ex:
+            LOG.exception(_("Error detaching volume %(volume)s, "
+                            "due to remove export failure."),
+                          {"volume": volume_id})
+            raise exception.RemoveExportException(volume=volume_id, reason=ex)
 
         self._notify_about_volume_usage(context, volume, "detach.end")
 
@@ -864,15 +871,6 @@ class VolumeManager(manager.SchedulerDependentManager):
             LOG.error(err_msg)
             raise exception.VolumeBackendAPIException(data=err_msg)
 
-        try:
-            LOG.debug(_("volume %s: removing export"), volume_id)
-            self.driver.remove_export(context.elevated(), volume_ref)
-        except Exception as ex:
-            LOG.exception(_("Error detaching volume %(volume)s, "
-                            "due to remove export failure."),
-                          {"volume": volume_id})
-            raise exception.RemoveExportException(volume=volume_id, reason=ex)
-
     def accept_transfer(self, context, volume_id, new_user, new_project):
         # NOTE(flaper87): Verify the driver is enabled
         # before going forward. The exception will be caught
@@ -882,7 +880,30 @@ class VolumeManager(manager.SchedulerDependentManager):
         # NOTE(jdg): need elevated context as we haven't "given" the vol
         # yet
         volume_ref = self.db.volume_get(context.elevated(), volume_id)
-        self.driver.accept_transfer(context, volume_ref, new_user, new_project)
+
+        # NOTE(jdg): Some drivers tie provider info (CHAP) to tenant
+        # for those that do allow them to return updated model info
+        model_update = self.driver.accept_transfer(context,
+                                                   volume_ref,
+                                                   new_user,
+                                                   new_project)
+
+        if model_update:
+            try:
+                self.db.volume_update(context,
+                                      volume_id,
+                                      model_update)
+            except exception.CinderException:
+                with excutils.save_and_reraise_exception():
+                    LOG.exception(_("Failed updating model of "
+                                    "volume %(volume_id)s "
+                                    "with drivers update %(model)s "
+                                    "during xfr.") %
+                                  {'volume_id': volume_id,
+                                   'model': model_update})
+                    self.db.volume_update(context.elevated(),
+                                          volume_id,
+                                          {'status': 'error'})
 
     def _migrate_volume_generic(self, ctxt, volume, host, new_type_id):
         rpcapi = volume_rpcapi.VolumeAPI()
