@@ -26,71 +26,17 @@ from pylint import lint
 from pylint.reporters import text
 from six.moves import cStringIO as StringIO
 
-ignore_codes = [
-    # Note(maoy): E1103 is error code related to partial type inference
-    "E1103"
-]
-
-ignore_messages = [
-    # Note(maoy): this error message is the pattern of E0202. It should be
-    # ignored for cinder.tests modules
-    "An attribute affected in cinder.tests",
-
-    # Note(fengqian): this error message is the pattern of [E0611].
-    "No name 'urllib' in module '_MovedItems'",
-
-    # Note(e0ne): this error message is for SQLAlchemy update() calls
-    # It should be ignored because use six module to keep py3.X compatibility.
-    # in DB schema migrations.
-    "No value passed for parameter 'dml'",
-
-    # Note(xyang): these error messages are for the code [E1101].
-    # They should be ignored because 'sha256' and 'sha224' are functions in
-    # 'hashlib'.
-    "Module 'hashlib' has no 'sha256' member",
-    "Module 'hashlib' has no 'sha224' member",
-
-    # Note(aarefiev): this error message is for SQLAlchemy rename calls in
-    # DB migration(033_add_encryption_unique_key).
-    "Instance of 'Table' has no 'rename' member",
-
-    # NOTE(geguileo): these error messages are for code [E1101], and they can
-    # be ignored because a SQLAlchemy ORM class will have __table__ member
-    # during runtime.
-    "Class 'ConsistencyGroup' has no '__table__' member",
-    "Class 'Cgsnapshot' has no '__table__' member",
-    "Class 'Group' has no '__table__' member",
-    "Class 'GroupSnapshot' has no '__table__' member",
-
-    # NOTE(xyang): this error message is for code [E1120] when checking if
-    # there are already 'groups' entries in 'quota_classes' `in DB migration
-    # (078_add_groups_and_group_volume_type_mapping_table).
-    "No value passed for parameter 'functions' in function call",
-
-    # NOTE(dulek): This one is related to objects.
-    "No value passed for parameter 'id' in function call",
-
-    # NOTE(geguileo): v3 common manage class for volumes and snapshots
-    "Instance of 'ManageResource' has no 'volume_api' member",
-    "Instance of 'ManageResource' has no '_list_manageable_view' member",
-]
-
-# Note(maoy):  We ignore cinder.tests for now due to high false
+# Note(maoy): E1103 is error code related to partial type inference
+ignore_codes = ["E1103"]
+# Note(maoy): the error message is the pattern of E0202. It should be ignored
+# for cinder.tests modules
+#Note(fengqian): the second error message is the pattern of [E0611].
+#It should be ignored because use six module to keep py3.X compatibility.
+ignore_messages = ["An attribute affected in cinder.tests", "No name 'urllib' in module '_MovedItems'"]
+# Note(maoy): we ignore all errors in openstack.common because it should be
+# checked elsewhere. We also ignore cinder.tests for now due to high false
 # positive rate.
-ignore_modules = ["cinder/tests/"]
-
-# Note(thangp): E0213, E1101, and E1102 should be ignored for only
-# cinder.object modules. E0213 and E1102 are error codes related to
-# the first argument of a method, but should be ignored because the method
-# is a remotable class method. E1101 is error code related to accessing a
-# non-existent member of an object, but should be ignored because the object
-# member is created dynamically.
-objects_ignore_codes = ["E0213", "E1101", "E1102"]
-# NOTE(dulek): We're ignoring messages related to non-existent objects in
-# cinder.objects namespace. This is because this namespace is populated when
-# registering the objects, and pylint is unable to detect that.
-objects_ignore_regexp = "Module 'cinder.objects' has no '.*' member"
-objects_ignore_modules = ["cinder/objects/"]
+ignore_modules = ["cinder/openstack/common/", "cinder/tests/"]
 
 KNOWN_PYLINT_EXCEPTIONS_FILE = "tools/pylint_exceptions"
 
@@ -146,16 +92,6 @@ class LintOutput(object):
             return True
         if any(msg in self.message for msg in ignore_messages):
             return True
-        if re.match(objects_ignore_regexp, self.message):
-            return True
-        if (self.code in objects_ignore_codes and
-            any(self.filename.startswith(name)
-                for name in objects_ignore_modules)):
-            return True
-        if (self.code in objects_ignore_codes and
-            any(self.filename.startswith(name)
-                for name in objects_ignore_modules)):
-            return True
         return False
 
     def key(self):
@@ -171,12 +107,7 @@ class LintOutput(object):
 
     def review_str(self):
         return ("File %(filename)s\nLine %(lineno)d:%(line_content)s\n"
-                "%(code)s: %(message)s" %
-                {'filename': self.filename,
-                 'lineno': self.lineno,
-                 'line_content': self.line_content,
-                 'code': self.code,
-                 'message': self.message})
+                "%(code)s: %(message)s" % self.__dict__)
 
 
 class ErrorKeys(object):
